<!-- #include virtual="/quickstart/winforms/include/header.inc" -->
      
<P>The application programming model for Win Forms is primarily comprised 
of forms, controls, and their events.&nbsp; The following areas of the Win 
Forms application model are covered in this topic:</P> 

<p>The Win Forms programming model centers around Forms, Controls and Events:</p>

<ul>
    <li><a target="content" href="#Forms">Forms</a>
    <li><a target="content" href="#Controls">Controls</a>
    <li><a target="content" href="#Events">Events</a>
    <li><a target="content" href="#Deterministic lifetime and Dispose">Deterministic lifetime and Dispose</a>
    <li><a target="content" href="#Sample">A Simple Sample Application</a>
</ul>


<a name="Forms">
<h5>Forms</h5>

<P>In Win Forms, the top level windows in your application are called 
<b>Forms</b>.  The Form class is a representation of any window displayed 
in your application.  You can use the <b>BorderStyle</b> property of the 
Form class to create standard, tool, borderless, and floating windows.  
You can also use the Form class to create modal windows such as a dialog 
box.  A special kind of form, the <a ref=WinFormsMDI.aspx>MDI form</a> can 
be created by setting the <b>MDIContainer</b> property of the Form class.  
An MDI form can contain other forms called MDI child forms within its 
client area.  The Form class provides built in support for keyboard 
handling (tab order) and scrolling of the contents of the form.</P> 

<P>When designing the user interface for your application, you typically 
create a class that derives from form.  You can then add controls to the 
form, set properties, create event handlers and add programming logic to 
your form.</P> 

<!--CONTROLS-->
<a name="Controls">
<h5>Controls</h5>

<P>The components that are added to a form, such as <b>Button</b>, 
<b>TextBox</b>, and <b>RadioButton</b> are called controls.  Win Forms 
includes all of the standard Windows controls as well as custom controls 
such as the Win Forms <b>DataGrid</b>.</P> 
      
<P>You typically interact with controls by setting properties to alter 
their appearance and behavior.  For example,&nbsp; the following subclass 
of Form adds a Button control to the form, sets its <b>Size</b> and 
<b>Location</b>, and adds it to the form:</P>

<Code:CodeSnippet runat=server>
<template name="CsTemplate">
    <xmp class=code1>
    
    public class HelloWorldForm : Form {
        
        private Button button1 = new Button() ;

        public HelloWorldForm() {
            
            this.Text = "Hello Win Forms World";
            this.AutoScaleBaseSize = new Size(5, 13);
            this.ClientSize = new Size(392, 117);

            button1.Location = new Point(256, 64);
            button1.Size = new Size(120, 40);
            button1.TabIndex = 1;
            button1.Text = "Click Me!";
    
            this.Controls.Add(button1);
        }
        
        public static int Main(string[] args) {
            Application.Run(new HelloWorldForm());
            return 0;
        }
    }
    </xmp>
</template>

<template name="VBTemplate">
   <xmp class=code1>

    Public Class HelloWorldForm
        Inherits System.WinForms.Form

        Private button1 As New Button

        Public Sub New()
           
            MyBase.New
    
            Me.Text = "Hello WinForms World"
            Me.AutoScaleBaseSize = new Size(5, 13)
            Me.ClientSize = new Size(392, 117)

            button1.Location = new Point(256, 64)
            button1.Size = new Size(120, 40)
            button1.TabIndex = 2
            button1.Text = "Click Me!"

            Me.Controls.Add(button1)
        
        End Sub

        'When the application is started show the Form
        Shared Sub Main()
            System.WinForms.Application.Run(New HelloWorldForm())
        End Sub
        
    End Class
   
   </xmp>
</template>
</Code:CodeSnippet>

<h6>Control state is modeless</h6>

<P>Win Forms provide limited restrictions as to when you can set 
properties for controls.  Controls do not have modes that prevent their 
state from being updated.  There are no properties that can only be set 
before you display a control, or that can only be set after you display a 
control, or that can only be set once a control has been added to a Form 
and so on.  As soon as you have created a new instance of a control you 
can alter its state.  For example the following code provides two examples 
that demonstrate valid ways of creating a Button control:</P> 

<Code:CodeSnippet runat=server>
<template name="CsTemplate">
    <xmp class=code1>
    
    Button button1 = new Button();
    button1.Location = new Point(256, 64);
    button1.Size = new Size(120, 40);
    button1.TabIndex = 1;
    button1.Text = "Click Me!";
    this.Controls.Add(button1);
    </xmp>
</template>

<template name="VBTemplate">
   <xmp class=code1>
    
    Dim button1 As New Button
    button1.Location = New Point(256, 64)
    button1.Size = New Size(120, 40)
    button1.TabIndex = 1
    button1.Text = "Click Me!"
    Me.Controls.Add(button1)
   </xmp>
</template>
</Code:CodeSnippet>
<br>
<Code:CodeSnippet runat=server>
<template name="CsTemplate">
    <xmp class=code1>
    
    Button button1 = new Button();
    this.Controls.Add(button1);
    button1.Location = new Point(256, 64);
    button1.Size = new Size(120, 40);
    button1.TabIndex = 1;
    button1.Text = "Click Me!";
    </xmp>
</template>

<template name="VBTemplate">
   <xmp class=code1>
    
    Dim button1 As New Button
    Me.Controls.Add(button1)
    button1.Location = New Point(256, 64)
    button1.Size = New Size(120, 40)
    button1.TabIndex = 1
    button1.Text = "Click Me!"
   </xmp>
</template>
</Code:CodeSnippet>

<P>Win Forms ensures that the code you create is valid.  For 
example,&nbsp; if you set a property that sets a Windows style bit for a 
Windows control that can only be set when it is created, the Win Forms 
control will "throw away" the underlying Windows control and create a new 
one for you.  The only time that this capability potentially is 
undesirable is if you bypass Win Forms and directly access the underlying 
HWND for the control.  You cannot keep a reference to the HWND as it may 
be made invalid by a property set in your code.</P> 


<!--EVENTS-->

<a name="Events">
<h5>Events</h5>

<P>The Win Forms programming model is event based.  When a control changes 
state, such as when the user clicks on a button, the control raises an 
event.  In order to handle an event your application&nbsp; registers an 
event-handling method for that event.  You register an event-handling 
method by calling the &quot;AddOnXXX&quot; method for the event (where XXX 
represents the name of the event you want to register), and pass a 
reference to the method that you want to be called when the event is 
raised.  For example,&nbsp; the following code creates a Button and 
registers an event-handling method for the click event:</P> 

<Code:CodeSnippet runat=server>
<template name="CsTemplate">
    <xmp class=code1>
    
    ....
    //Create the button</span>
    Button button1 = new Button() ;
    button1.Location = new Point(256, 64);
    button1.Size = new Size(120, 40);
    button1.Text = "Click Me!";
    
    //Register the event handler</span>
    <b>button1.AddOnClick(new System.EventHandler(buttonClicked));</b>
    ....
    
    //The event handling method</span>
    <b>private void buttonClicked(object sender, EventArgs evArgs)</b> {
        MessageBox.Show("Hello Win Forms World!");
    }

    </xmp>
</template>

<template name="VBTemplate">
   <xmp class=code1>
    
    ....
    'Create the button</span>
    Dim button1 As New Button
    button1.Location = New Point(256, 64)
    button1.Size = New Size(120, 40)
    button1.Text = "Click Me!"
    
    'Register the event handler</span>
    <b>button1.AddOnClick(AddressOf buttonClicked)</b>
    ....
    
    'The event handling method</span>
    <b>Private Sub buttonClicked(sender As Object, evArgs As EventArgs)</b>
        MessageBox.Show("Text is: '" + textBox1.Text + "'")
    End Sub

   </xmp>
</template>
</Code:CodeSnippet>

<P>An event-handling method is only called for a specific event for a 
specific control.  This allows you to avoid having a single method in your 
form that handles all events for all controls.  This feature makes your 
code easier to understand and maintain.  Furthermore because the Win Forms 
event architecture is based on <B>Delegates</B>, your event-handling 
methods are type safe and can be declared as private.  This capability 
allows your compiler to detect method signature mismatches at compile 
time.  It also keeps the public interface of your Form class uncluttered 
with public event-handling methods.  You can find more information about 
delegates in the NGWS SDK documentation. </p>


<h6>Event classes</h6>

<P>Each event has 2 supporting classes: 
<UL>
  <LI><B>The EventHandler delegate class</B> that is used to register your
    event- handling method. The signature of the EventHandler dictates the 
  signature of your event handling method. <BR>
  <LI><B>The EventArgs class</B> that contains data about the event 
  that has been raised. </LI></UL>
<P>The signature for an EventHandler is that the first argument contains a
reference to the 
object that fired the event (the sender) and that&nbsp; the second argument
contains data about the event, an instance of an EventArgs. For
example,&nbsp; the <b>Click</b> event on a Button uses the the following
event handler: </p>

<Code:CodeSnippet runat=server>
<template name="CsTemplate">
    <xmp class=code1>
    
    public delegate void EventHandler(object sender, EventArgs e);    
    ....
    public virtual void AddOnClick(EventHandler handler) ; 
    ....
    </xmp>
</template>
<template name="VBTemplate">
   <xmp class=code1>
    
    Public Delegate Sub EventHandler(sender As object, e As EventArgs)
    ....
    Public Overridable Sub AddOnClick(handler As EventHandler) 
    ....
   </xmp>
</template>
</Code:CodeSnippet>    
<br>
As a result, any event-handling method for the Click event must have the following signature: 
<br><br>

<Code:CodeSnippet runat=server>
<template name="CsTemplate">
    <xmp class=code1>
    
    &lt;access&gt; void &lt;name&gt;(object sender, EventArgs evArgs) 
    </xmp>
</template>
<template name="VBTemplate">
   <xmp class=code1>
    
    &lt;access&gt; Sub &lt;name&gt;(sender As object, e As EventArgs)
   </xmp>
</template>
</Code:CodeSnippet>    

<p>For strongly typed languages, a compile time error will occur if the 
event-handling method's signature do not match the event handler 
signature.</p>
    
<P>Many events use the generic EventHandler and EventArgs classes.  
However, some events require additional information specific to the type 
of event that is raised.  For example, the mouse movement events include 
information about the position of the mouse.  These events define their 
own classes that inherit from the EventHandler and EventArg classes.  For 
example,&nbsp; the <b> MouseDown</b> event uses the <b> 
MouseEventHandler</b> and <b>MouseEventArgs</b>.  All EventArgs must 
derive from the EventArgs class.  

<h6>Event naming conventions</h6>

<P>Some state changes cause an event to be raised both before and after 
the state change.  The event that is raised prior to a state change is 
typically suffixed with "ing".  The event that is raised after a state 
change is typically suffixed with "ed".  For example, the 
<b>SessionEnding</b> event and <b> SessionEnded</b> even.  If a state 
change causes only a single event to be fired then that event typically 
does not have a suffix.  For example, the <b> Click</b> event.</P> 

<h6>Cancellable Events</h6> 

<P>Depending on the situation in your application, you may want to cancel 
an event.  Certain events can be cancelled.  These events use the <b> 
CancelEventHandler</b> and <b>CancelEventArgs</b> classes.  The 
CancelEventArgs contains a property called <B>Cancel</B>.  If this 
property is is set to <b> true</b>, when the event-handling method 
returns, the event will be cancelled.  Typically only events that are 
raised prior to a state change are cancellable.  Cancelling the event 
cancels the state change.  </p>

<h6>Adding, Removing and Raising Events</h6>

<P>Events on controls are exposed using a set of three methods:

<TABLE border=0 cellPadding=5 class=mydd>
 <TBODY>
 <TR>
   <TD vAlign=top><STRONG>AddOn&lt;EventName&gt;</STRONG></TD>
   <TD>
     <P>The AddOn&lt;EventName&gt; method registers an event-handling 
     method with an event. For example, to register the 
     Click event of a Button you would call the <b> Button.AddOnClick</b> method. 
   </P></TD></TR>
 <TR>
   <TD vAlign=top><STRONG>RemoveOn&lt;EventName&gt;</STRONG></TD>
   <TD>
     <P>The RemoveOn&lt;EventName&gt; method removes an event handling 
     method that was previously registered with an event. </P></TD></TR>
 <TR>
   <TD vAlign=top><STRONG>On&lt;EventName&gt;</STRONG></TD>
   <TD>
     <P>The protected On&lt;EventName&gt; method raises the event. For
     example,&nbsp; the <b> OnPaint</b> method of the Form class raises the
     <b> Paint</b> event. Typically the 
     On&lt;EventName&gt; method is protected and is only intended for use 
     by control authors who are overriding the behavior of the the base 
     class implementation. </P>
   </TD>
  </TR>
  </TBODY>
</TABLE>

<h6>Handling multiple events with a single event handling method</h6>

<P>If you wish to handle multiple events with a single event handler you 
can do this by registering the same method with multiple events.  Both 
events would have to have the same signature.  When you use a single 
event-handling method for multiple events you can determine which control 
raised&nbsp; the event from the sender parameter.  The following example 
shows a single event-handling method being used to handle events from 2 
Button controls:</P> 
      
<Code:CodeSnippet runat=server>
<template name="CsTemplate">
    <xmp class=code1>

    ....
    Button button1 = new Button() ;
    Button button2 = new Button() ;
    ....
    button1.AddOnClick(new System.EventHandler(buttonClicked));
    button2.AddOnClick(new System.EventHandler(buttonClicked));
    ....
    
    //The event handling method</span>
    private void buttonClicked(object sender, EventArgs evArgs) {
        if (sender==button1) {
            MessageBox.Show("Button1 Pushed!");
        } else if (sender==button2) {
            MessageBox.Show("Button2 Pushed!");
        }
    }

    
    </xmp>
</template>
<template name="VBTemplate">
   <xmp class=code1>
    
    ....
    Dim button1 As New Button
    Dim button2 As New Button
    ....
    button1.AddOnClick(AddressOf buttonClicked)
    button2.AddOnClick(AddressOf buttonClicked)
    ....
    
    'The event handling method</span>
    <b>Private Sub buttonClicked(sender As Object, evArgs As EventArgs)</b>
        If (sender = button1) Then
            MessageBox.Show("Button1 Pushed!")
        Else If (sender = button2) Then
            MessageBox.Show("Button2 Pushed!")
        End If
    End Sub
   
   </xmp>
</template>
</Code:CodeSnippet>    


<br>
<a name="Deterministic lifetime and Dispose">
<h5>Deterministic lifetime and Dispose</h5> 

<P>The NGWS component model provides the <b>Dispose</b> method in the 
<b>Component</b> class.  The Dispose method is called method when a&nbsp; 
component is no longer required.  For example, Win Forms calls the Dispose 
on a form and all the controls contained within that form when the form is 
closed.  You typically use Dispose to free large resources in a timely 
manner and to remove references to other objects so that they can be 
garbage collected.  It is also called to stop any executing program logic 
associated with the form.  You should keep the code in your Dispose method 
as simple and robust as possible because if the Dispose method fails, 
large resources may not be released from memory.</P> 

<a name="Sample">
<h5>Putting it all together - a simple Win Forms application</h5>

<P>The following sample demonstrates the concepts mentioned previously.  
It shows how to: 
<UL>
<LI>Create and display a Form as the main entry point of an application 
<LI>Add controls to a Form 
<LI>Set properties on the controls 
<LI>Register event-handling methods with controls 
<LI>Get property values from a control 
<LI>Display text in a Message Box 
<LI>Add code to the Dispose method that gets executed when the form is 
closed. 
</UL>

<Code:CodeSnippet runat=server>
    
    <template name="CsTemplate">
        <Acme:SourceRef 
        RunSample="/quickstart/winforms/Samples/Cs/HelloWorldForm" 
        ViewSource="/quickstart/winforms/Samples/Cs/HelloWorldForm/HelloWorldForm.src"
        Icon = "/quickstart/winforms/images/wflink.jpg"
        Caption="C# Hello World"
        MapRunSamplePath=true
        runat="server" />
    </template>
    
    <template name="VBTemplate">
        <Acme:SourceRef 
        RunSample="/quickstart/winforms/Samples/VB/HelloWorldForm" 
        ViewSource="/quickstart/winforms/Samples/VB/HelloWorldForm/HelloWorldForm.src"
        Icon = "/quickstart/winforms/images/wflink.jpg"
        Caption="VB Hello World"
        MapRunSamplePath=true
        runat="server" />
    </template>
    
</Code:CodeSnippet>


<!-- #include virtual="/quickstart/winforms/include/footer.inc" -->


