<!-- #include virtual="/quickstart/winforms/include/header.inc" -->

<h4>Hosting an ActiveX Control on a Win Form</h4>
      
<P>This topic demonstrates how to host the <b> WebBrowser</b> ActiveX 
control in a form by building an MDI WebBrowser application.  

<h5>Win Forms and ActiveX Controls</h5>

<p>Win Forms can only host Win Forms controls.  All Win Forms controls are 
classes that are derived from the <b>System.WinForms.Control</b> class.  
In order for an ActiveX control to be hosted on a form, it must appear to 
be a Win Forms control.  Conversely an ActiveX control must appear to be 
hosted in an ActiveX control container.  The <b> 
System.WinForms.AxHost</b> class (which derives from 
<b>System.WinForms.RichControl</b>) is a Win Forms control "on the 
outside" and an ActiveX control container "on the inside".  In order to 
host an ActiveX Control you need to create a &quot;wrapper&quot; class 
that derives from <b>System.WinForms.AxHost</b>.  This control hosts the 
ActiveX control and exposes its properties, methods, and events (PMEs) as 
PMEs of the generated conrtrol: <BR> 
      
<br>
<img src=/quickstart/winforms/images/aximp.gif>
<br>

<P>All conversions are done for an entire ActiveX control type library at 
one time.  You cannot use <b> aximp</b> to generate type information for a 
subset of the types defined within a single type library.  The output of 
aximp is a set of binary files that contain the COM+ metadata and control 
implementation for the types defined within the original type library.  
The generated files are named according to the following pattern: 
      
 <UL>
   <LI>COM+ proxy for COM2 types: <PROGID>.dll 
   <LI>Win Forms proxy for ActiveX Control: Ax<PROGID>.dll 
</LI></UL>

<P>You can examine these files with tools such as Metainfo.exe or 
Ildasm.exe.  
      
<P><B>Beta Warning: If the name of the COM2 type library progid has the 
same name as the output proxy name - for instance SHDOCVW.DLL - then the 
original type library may be overwritten.  Do not use aximp in the 
directory that contains your type library.  </B></P> 

<h5>Creating an ActiveX Control Wrapper</h5>

<P>You create the the ActiveX control wrapper using the aximp.exe tool 
included in the SDK.  The following is an example of how to call aximp: </p>

<Code:CodeSnippet runat=server>
<template name="CsTemplate">
    <xmp class=code1>
    
    aximp c:\winnt\system32\shdocvw.dll
    </xmp>
</template>

<template name="VBTemplate">
   <xmp class=code1>
   
   aximp c:\winnt\system32\shdocvw.dll
   </xmp>
</template>
</Code:CodeSnippet>
<br>

<h5>Using Wrapper Control</h5>

<P>Once you have created the control&nbsp; wrapper class you can use it in 
the same way that you would any Win Forms control.  The following example 
demonstrates how to add a <b> WebBrowser</b> control to a Form:</P> 

<Code:CodeSnippet runat=server>
<template name="CsTemplate">
    <xmp class=code1>
    
    ....
    using AxSHDocVw;
    ....
    AxWebBrowser1.BeginInit();
    ....
    AxWebBrowser AxWebBrowser1= new AxWebBrowser();
    AxWebBrowser1.Size = new System.Drawing.Size(292, 273);
    AxWebBrowser1.TabIndex = 0;
    AxWebBrowser1.Dock = System.WinForms.DockStyle.Fill;
    ....
    this.Controls.Add(AxWebBrowser1);
    ....
    AxWebBrowser1.EndInit();
    ....
    </xmp>
</template>

<template name="VBTemplate">
   <xmp class=code1>

    ....
    Imports AxSHDocVw
    ....
    AxWebBrowser1.BeginInit()
    ....
    AxWebBrowser1.Location = New System.Drawing.Point(0, 24)
    AxWebBrowser1.Size = New System.Drawing.Size(650, 456)
    AxWebBrowser1.Dock = System.WinForms.DockStyle.Fill
    AxWebBrowser1.TabIndex = 3
    ....
    Me.Controls.Add(AxWebBrowser1)
    ....
    AxWebBrowser1.EndInit()
    ....
   
   </xmp>
</template>
</Code:CodeSnippet>

<P>Once you have finished writing the code for your form you can build it 
and pass in references to the wrapper DLLs:</P> 
      
<Code:CodeSnippet runat=server>
<template name="CsTemplate">
    <xmp class=code1>
    
    csc.exe /debug+   /R:System.DLL /R:System.WinForms.DLL /R:System.Drawing.DLL 
    /R:Microsoft.Win32.InterOp.DLL /R:shdocvw.dll /R:AxShDocVw.DLL
    /out:MDIBrowser.exe *.cs   
    
    </xmp>
</template>

<template name="VBTemplate">
   <xmp class=code1>
   
    vbc.exe /debug+  /R:System.DLL /R:System.WinForms.DLL /R:System.Drawing.DLL 
    /R:Microsoft.Win32.InterOp.DLL /R:shdocvw.dll /R:AxShDocVw.DLL
    /out:MDIBrowser.exe *.VB
    
   </xmp>
</template>
</Code:CodeSnippet>


<h5>Web Browser Control Sample</h5>
<P>The following sample demonstrates how to host an ActiveX control. <BR><BR>
<P>To view and run this sample: </p>

<Code:CodeSnippet runat=server>
    
    <template name="CsTemplate">
        <Acme:SourceRef 
        RunSample="/quickstart/winforms/Samples/Cs/AxHosting" 
        ViewSource="/quickstart/winforms/Samples/Cs/AxHosting/AxHosting.src"
        Icon = "/quickstart/winforms/images/wflink.jpg"
        Caption="C# Browser Sample"
        MapRunSamplePath=true
        runat="server" />
    </template>
    
    <template name="VBTemplate">
        <Acme:SourceRef 
        RunSample="/quickstart/winforms/Samples/VB/AxHosting" 
        ViewSource="/quickstart/winforms/Samples/VB/AxHosting/AxHosting.src"
        Icon = "/quickstart/winforms/images/wflink.jpg"
        Caption="VB Browser Sample"
        MapRunSamplePath=true
        runat="server" />
    </template>
    
</Code:CodeSnippet>

<h5>Beta Caveats</h5> 

<P>The Win Forms team is testing ActiveX Control Hosting compatibility 
with a wide range of ActiveX controls.  However this testing is in 
progress and so some ActiveX Controls may work better than others.  </P>
      
<P>If you find issues with a control that you are trying to use, please 
report the problem via the Beta bug reporting process.</P> 


<!-- #include virtual="/quickstart/winforms/include/footer.inc" -->
