<!-- #include virtual="/quickstart/winforms/include/header.inc" -->

<h4>Win Forms Databinding</h4>

<p>Before reading this Quick Start you should read the <a 
href="DataAccessPlaceHolder.aspx">ADO+ Overview</a></p> 

<p>The last three samples use Web Services. You should read the <a 
href="WebServicesPlaceHolder.aspx">Web Services Overview</a> before reviewing those samples.</p> 

<ul>
    <li><a target="content" href="#Introduction">Introduction</a>
    <li><a target="content" href="#Simple Databinding">Simple Databinding</a>
    <li><a target="content" href="#Binding to a Combobox or ListBox">Binding to a Combobox or ListBox</a>
    <li><a target="content" href="#Binding to a DataGrid">Binding to a DataGrid</a>
    <li><a target="content" href="#Using a Web Service to retrieve a DataSet">Using a Web Service to retrieve a DataSet</a>
    <li><a target="content" href="#Master Detail Forms">Master Detail Forms</a>
    <li><a target="content" href="#Customer Details Form">Customer Details Form</a>
</ul>

<a name="Introduction">
<h5>Introduction</h5>

<p>Data binding provides a simple, convenient, powerful, transparent way 
for developers to create a read/write link between the controls on a Form
and the data in their application (their datamodel).</p> 

<p>Win Forms supports databinding to ADO+ DataSets, Arrays, ArrayLists and 
so on.  A control can be databound to any collection that supports indexed 
access to the elements in that collection - to be specific to any 
collection that implements the IList inteface.</p> 

<h6>Simple Data Binding</h6> 

<p>Simple Data Binding means databinding a single value within the 
datamodel to a single property of a control.  For example databinding 
TextBox1.Text to Customer.Name. Simple binding is managed via the 
Bindings collection on each control.</p>

<h6>Complex Data Binding</h6> 

<p>Complex Data Binding means databinding a control to a collection rather 
a single item within the collection.  For example the DataGrid has a 
DataSource property that can be set to an entire DataSet or Array.  The 
DataGrid understands how to extract information from the DataSource and 
display it.  ListBox and Combobox also use Complex Data Binding</p> 

<h6>One Way and Two Way Data Binding</h6>

<p><b>One Way Data Binding</b> A property of a control can be bound to the 
datamodel for read-only or presentation purposes.  When data binding is 
set up in this fashion, the property will reflect the value of the data, 
but direct changes to the property will not be reflected in the datamodel.  

<p><b>Two Way Data Binding</b> A property of a control can be bound to the 
datamodel in a read/write fashion.  When data binding is set up in this 
fashion, the property will reflect the value of the data, and  
changes to the property will be propogated to the datamodel.  


<h6>The BindingManager</h6> 

<p>Each Form has a BindingManager.  The BindingManager is responsible for 
managing the collections that controls are bound to.  It manages currency 
and dependency.  

<p><b>Currency:</b> The BindingManager maintains a current position for 
each collection.  Simple Databinding uses this current position to 
determine which object in the collection to data bind a control property 
to.  As the current position is changed so does the object that a control 
property is bound to.  See <a target="content" href="#Simple 
Databinding">Simple Databinding.</a></p> 

<p><b>Dependency:</b> The BindingManager maintains dependency relationships 
between collections.  This allows the creation of Master/Details Forms - 
see <a target="content" href="#Master Detail Forms">Master Detail 
Forms.</a></p> 

<a name="Simple Databinding">
<h5>Simple Databinding</h5>
                                                                          
<p>This sample demonstrates simple databinding of the Text property on a 
set of TextBoxes to the properties of a Customer object stored as a List 
of Customers.  You add simple data bindings using the Binding collection 
on a control:</p> 

<Code:CodeSnippet runat=server> 
<template name="CsTemplate">
    <xmp class=code1>
    
    textBoxID.Bindings.Add("Text", custList, "CustomerID");
    textBoxTitle.Bindings.Add("Text", custList, "ContactTitle");
    textBoxLastName.Bindings.Add("Text", custList, "ContactName");
    textBoxFirstName.Bindings.Add("Text", custList, "CompanyName");
    textBoxAddress.Bindings.Add("Text", custList, "Address");

    </xmp>
</template>
<template name="VBTemplate">
   <xmp class=code1>
Visual Basic in line code sample not available for the PDC Release. Refer to the complete Visual Basic sample.
   </xmp>
</template>
</Code:CodeSnippet>

<p>Each TextBox.Text is bound to the current Customer object as maintained by 
the BindingManager.  To change the current object you increment or decrement 
the Position property for the collection via the BindingManager.  For 
example you would implement a "Move Next" button by handling the button 
click event as follows:</p> 

<Code:CodeSnippet runat=server> 
<template name="CsTemplate">
    <xmp class=code1>
    
    private void buttonMoveNext_Click(object sender, System.EventArgs e) {
        this.BindingManager[custList].Position++;
    }
    </xmp>
</template>
<template name="VBTemplate">
   <xmp class=code1>
Visual Basic in line code sample not available for the PDC Release. Refer to the complete Visual Basic sample.

   </xmp>
</template>
</Code:CodeSnippet>

<p>The BindingManager raises an event whenever the position changes:</p>


<Code:CodeSnippet runat=server> 
<template name="CsTemplate">
    <xmp class=code1>
    
    ....
    
    this.BindingManager[custList].AddOnPositionChanged(new System.EventHandler(customer_PositionChanged));
    
    ....
    
    private void customer_PositionChanged(object sender, System.EventArgs e) {
        textBoxPosition.Text = "Record " + (this.BindingManager[custList].Position + 1) + " of " + custList.Length;
    }

    </xmp>
</template>
<template name="VBTemplate">
   <xmp class=code1>
Visual Basic in line code sample not available for the PDC Release. Refer to the complete Visual Basic sample.

   </xmp>
</template>
</Code:CodeSnippet>


<p>To view and run this sample:
<br><br>
<Code:CodeSnippet runat=server>
    
    <template name="CsTemplate">
        <Acme:SourceRef 
        RunSample="/quickstart/winforms/Samples/Cs/Data/SimpleBinding" 
        ViewSource="/quickstart/winforms/Samples/Cs/Data/SimpleBinding/SimpleBinding.src"
        Icon = "/quickstart/winforms/images/wflink.jpg"
        Caption="C# Simple Data binding"
        MapRunSamplePath=true
        runat="server" />
    </template>
    
    <template name="VBTemplate">
        <Acme:SourceRef 
        RunSample="/quickstart/winforms/Samples/VB/Data/SimpleBinding" 
        ViewSource="/quickstart/winforms/Samples/VB/Data/SimpleBinding/SimpleBinding.src"
        Icon = "/quickstart/winforms/images/wflink.jpg"
        Caption="VB Simple Data binding"
        MapRunSamplePath=true
        runat="server" />
    </template>
    
</Code:CodeSnippet>

<a name="Binding to a Combobox or ListBox">
<h5>Binding to a Combobox or ListBox</h5>

<p>This sample demonstrates databinding a Combobox. Databinding a ListBox 
follows exactly the same model. 

<p>To databind the list of items to be displayed set the DataSource and 
DisplayMember properties of the ComboBox.  For example the following code 
data binds a ComboBox to an array of State objects.  The DisplayMember 
property is used to determine what property of the State object to display 
in the ComboBox:</p> 

<Code:CodeSnippet runat=server>
<template name="CsTemplate">
    <xmp class=code1>
    
    ....
    
    public struct State {
        private string shortName, longName;

        public State(string longName , string shortName) { 
            this.shortName = shortName ; this.longName = longName ;
        }

        public string ShortName { get { return shortName; } }
        public string LongName { get { return longName; } }
    }
    
    ....
    
    private State[] States  = new State[] { 
      new State("Alabama","AL"),
    ....
      new State("Washington" ,"WA),
    ....
    } ;                                       

    ....
    
    comboBoxState.DataSource=States;
    comboBoxState.DisplayMember="LongName";
    
    ....
    
    </xmp>
</template>

<template name="VBTemplate">
   <xmp class=code1>
Visual Basic in line code sample not available for the PDC Release. Refer to the complete Visual Basic sample.

   </xmp>
</template>

</Code:CodeSnippet>

<p>Typically in a databound form a ComboBox is used to lookup up a value.  
In this example the form displays a Customer object.  Each Customer object 
has a Region property that contains a State abbreviation. We want to
display a list of full State names for the user to select from. When the 
user selects a particular State, we want the Customer Region to be updated 
with the State Abbreviation rather than the full State name. In order to 
achieve this we:
<ul>
<li>set the ComboBox up as before 
<li>set the ValueMember property to point to the State Abbreviation 
property on the State object - State.ShortName 
<li>Simple Databind the SelectedValue to Customer.Region
</ul>
<p>The ValueMember property determines what value gets pushed into SelectedValue. So 
in our example whenever the user selects a State by State.LongName, the SelectedValue is
the State.ShortName. Whenever the SelectedValue changes, the databinding pushes the new 
value into the Customer object.</p>

<Code:CodeSnippet runat=server>
<template name="CsTemplate">
    <xmp class=code1>
      
      comboBoxState.DataSource=States;
      comboBoxState.DisplayMember="LongName";
      comboBoxState.ValueMember="ShortName";
      comboBoxState.Bindings.Add("SelectedValue", customersDataSet1, "Customers.Region");
    </xmp>
</template>

<template name="VBTemplate">
   <xmp class=code1>
Visual Basic in line code sample not available for the PDC Release. Refer to the complete Visual Basic sample.

   </xmp>
</template>

</Code:CodeSnippet>

<p>To view and run this sample:
<br><br>
<Code:CodeSnippet runat=server>
    
    <template name="CsTemplate">
        <Acme:SourceRef 
        RunSample="/quickstart/winforms/Samples/Cs/Data/ComboBoxBinding" 
        ViewSource="/quickstart/winforms/Samples/Cs/Data/ComboBoxBinding/ComboBoxBinding.src"
        Icon = "/quickstart/winforms/images/wflink.jpg"
        Caption="C# Combobox binding"
        MapRunSamplePath=true
        runat="server" />
    </template>
    
    <template name="VBTemplate">
        <Acme:SourceRef 
        RunSample="/quickstart/winforms/Samples/VB/Data/ComboBoxBinding" 
        ViewSource="/quickstart/winforms/Samples/VB/Data/ComboBoxBinding/ComboBoxBinding.src"
        Icon = "/quickstart/winforms/images/wflink.jpg"
        Caption="VB Combobox binding"
        MapRunSamplePath=true
        runat="server" />
    </template>
    
</Code:CodeSnippet>

<a name="Binding to a DataGrid">
<h5>Binding to a DataGrid</h5>

<p>The DataGrid displays all the information in an array, collection or 
ADO+ DataTable as a series of rows.  Each row can be edited in place.  
Changes are automatically pushed back into the underlying collection of 
objects as the user moves from row to row.</p> 

<p>When the DataGrid is used to view a DataSet, the user can navigate 
across the DataTables in a DataSet via their relationships.</p> 

<p>In order to use a DataGrid you simply set the DataSource property to 
the list of objects to display.  If the DataSource is a DataSet you also 
need to set the DataMember property to the DataTable to display:</p> 

<Code:CodeSnippet runat=server>
<template name="CsTemplate">
    <xmp class=code1>
     
     dataGrid1.Size = new System.Drawing.Size(584, 336);
     dataGrid1.DataSource = customersDataSet1;
     dataGrid1.DataMember = "Customers";
    </xmp>
</template>

<template name="VBTemplate">
   <xmp class=code1>
Visual Basic in line code sample not available for the PDC Release. Refer to the complete Visual Basic sample.


</xmp> 
</template>
</Code:CodeSnippet> 

<p>There are a set of properties on the DataGrid that allow you to change 
the way it displays data.  For example you can set the AlternatingBackColor
property to cause alternate rows to be displayed with a different BackColor:</p>

<Code:CodeSnippet runat=server>
<template name="CsTemplate">
    <xmp class=code1>
     
		dataGrid1.DataSource = customersDataSet1;
		dataGrid1.DataMember = "Customers";
		dataGrid1.ForeColor = System.Drawing.Color.Navy;
		dataGrid1.BackColor = System.Drawing.Color.Gainsboro;
		dataGrid1.AlternatingBackColor = System.Drawing.Color.WhiteSmoke;
    </xmp>
</template>

<template name="VBTemplate">
   <xmp class=code1>
Visual Basic in line code sample not available for the PDC Release. Refer to the complete Visual Basic sample.


</xmp> 
</template>
</Code:CodeSnippet> 

<p>The DataGrid sample demonstrates how to load a DataSet and displays its contents 
in a DataGrid:</p>
<Code:CodeSnippet runat=server>
    
    <template name="CsTemplate">
        <Acme:SourceRef 
        RunSample="/quickstart/winforms/Samples/Cs/Data/Grid" 
        ViewSource="/quickstart/winforms/Samples/Cs/Data/Grid/Grid.src"
        Icon = "/quickstart/winforms/images/wflink.jpg"
        Caption="C# Grid binding"
        MapRunSamplePath=true
        runat="server" />
    </template>
    
    <template name="VBTemplate">
        <Acme:SourceRef 
        RunSample="/quickstart/winforms/Samples/VB/Data/Grid" 
        ViewSource="/quickstart/winforms/Samples/VB/Data/Grid/Grid.src"
        Icon = "/quickstart/winforms/images/wflink.jpg"
        Caption="VB Grid binding"
        MapRunSamplePath=true
        runat="server" />
    </template>
    
</Code:CodeSnippet>

<a name="Using a Web Service to retrieve a DataSet">
<h5>Using a Web Service to retrieve a DataSet</h5>

<p>Windows DNA applications expose services as Web Services.  Web Services 
can return data.  Win Forms applications can use a Web Service to retrieve 
data and data bind to that returned data.  This sample demonstrates data 
binding to data return from a Web Service.</p> 

<p>Before walking through this sample you should make yourself familar 
with Web Services by reading the <a 
href=/quickstart/winforms/doc/WebServicesPlaceHolder.aspx>Web Services 
Overview</a></p> 

<p>The first step is to create a Web Service that returns a DataSet:</p>

<Code:CodeSnippet runat=server>
<template name="CsTemplate">
    <xmp class=code1>
    
&lt%@ WebService Language="C#" %%gt

using System.Web.Services;
using System.Data;
using System.Data.ADO;
using Microsoft.Samples.WinForms.Cs.Grid.Data;

public class CustomersList : WebService {

     [ WebMethod ]
     public CustomersDataSet GetCustomers() {
         CustomersDataSet customersDataSet1 = new CustomersDataSet();
         ADOConnection con = new ADOConnection("Provider=SQLOLEDB;Data Source=markbou00d;Database=northwind;User Id=sa;");
         ADODataSetCommand cmdCustomers = new ADODataSetCommand("Select * from Customers", con);
         ADODataSetCommand cmdOrders = new ADODataSetCommand("Select * from Orders", con);
         cmdCustomers.FillDataSet(customersDataSet1, "Customers");
         cmdOrders.FillDataSet(customersDataSet1, "Orders");
         return customersDataSet1 ;
     }
     
}
    </xmp>
</template>

<template name="VBTemplate">
   <xmp class=code1>
Visual Basic in line code sample not available for the PDC Release. Refer to the complete Visual Basic sample.


   </xmp>
</template>

</Code:CodeSnippet>
<br>
<p>You can view this Web Service at: <a target="_NEW" 
href="/quickstart/winforms/Samples/Cs/Data/WebServiceBinding/SimpleCustomersWebService.asmx">CustomersList</a></p> 

<p>Having created the Web Service you then need to create an SDL file that 
defines the schema for that Web Service.  You can get the SDL by connecting 
to the Web Service with the &quot;?SDL&quot; parameter: 
<a target="_NEW" 
href="/quickstart/winforms/Samples/Cs/Data/WebServiceBinding/SimpleCustomersWebService.asmx?SDL">CustomersList 
SDL</a>.  

<p>Once you have the SDL file you can then create a client proxy source file 
using the WebServiceUtil tool:</p> 

<template name="CsTemplate">
    <xmp class=code1>
webserviceutil 
    -client \
    http://locahost/QuickStart/winforms/samples/cs/data/webservicebinding/SimpleCustomersWebService.asmx \
    SimpleCustomersWebService.SDL \
    CSharp \
    SimpleWebService
    </xmp>
</template>

<template name="VBTemplate">
   <xmp class=code1>
Visual Basic in line code sample not available for the PDC Release. Refer to the complete Visual Basic sample.


   </xmp>
</template>

</Code:CodeSnippet>

<p>Once you have the proxy source file you can compile it into your 
application and use it to retrieve the data from the Web Service:</p>

<Code:CodeSnippet runat=server>

<template name="CsTemplate">
    <xmp class=code1>
    
    CustomersList custList1 = new CustomersList();
    DataSet ds1 = custList1.GetCustomers();
    dataGrid1.DataSource=ds1;
    </xmp>
</template>

<template name="VBTemplate">
   <xmp class=code1>
Visual Basic in line code sample not available for the PDC Release. Refer to the complete Visual Basic sample.


   </xmp>
</template>

</Code:CodeSnippet>
 
<p>The Web Services sample demonstrates how to load a DataSet from a 
Web Service and display its contents in a DataGrid:</p>
<Code:CodeSnippet runat=server> 
    
    <template name="CsTemplate">
        <Acme:SourceRef 
        RunSample="/quickstart/winforms/Samples/Cs/Data/WebServiceBinding" 
        ViewSource="/quickstart/winforms/Samples/Cs/Data/WebServiceBinding/WebServiceBinding.src"
        Icon = "/quickstart/winforms/images/wflink.jpg"
        Caption="C# Grid binding to a WebService"
        MapRunSamplePath=true
        runat="server" />
    </template>
    
    <template name="VBTemplate">
        <Acme:SourceRef 
        RunSample="/quickstart/winforms/Samples/VB/Data/WebServiceBinding" 
        ViewSource="/quickstart/winforms/Samples/VB/Data/WebServiceBinding/WebServiceBinding.src"
        Icon = "/quickstart/winforms/images/wflink.jpg"
        Caption="VB Grid binding to a Web Service"
        MapRunSamplePath=true
        runat="server" />
    </template>
    
</Code:CodeSnippet>

<a name="Master Detail Forms">
<h5>Master Detail Forms</h5>

<p>In database applications, it's often useful to simultaneously view a 
record with a group of related records.  For example, you may want to view 
a customer and the current orders for the customer.  A common way 
to accomplish this is to create a Master/Detail form.

<p>This sample displays Customers and the Orders for each Customer in 2 DataGrids.
The first DataGrid displays the list of Customers.  The 
second DataGrid displays the list of Orders.  As the selected Customer 
changes, the second DataGrid will update to display the Orders for that 
Customer.</p> 

<p>In order to link the 2 DataGrids together you need set the DataSource of the 
2 DataGrids to the same DataSet. You also need to set the DataMembers so that 
the Win Forms BindingManager understands that they are related. You do
this by setting the DataMember for the second DataGrid to the name of the relationship 
between the Customers and Orders tables - &quot;Customers.CustomersOrders&quot;:</p>

<Code:CodeSnippet runat=server> 

<template name="CsTemplate">
    <xmp class=code1>
    
    dataGrid1.DataSource = customersAndOrdersDataSet1;
    dataGrid1.DataMember = "Customers";
   
    dataGrid2.DataSource = customersAndOrdersDataSet1;
    dataGrid2.DataMember = "Customers.CustomersOrders";

    </xmp>
</template>

<template name="VBTemplate">
   <xmp class=code1>
Visual Basic in line code sample not available for the PDC Release. Refer to the complete Visual Basic sample.


   </xmp>
</template>

</Code:CodeSnippet>

<p>To view and run this sample:
<br><br>
<Code:CodeSnippet runat=server>
    
    <template name="CsTemplate">
        <Acme:SourceRef 
        RunSample="/quickstart/winforms/Samples/Cs/Data/MasterDetails" 
        ViewSource="/quickstart/winforms/Samples/Cs/Data/MasterDetails/MasterDetails.src"
        Icon = "/quickstart/winforms/images/wflink.jpg"
        Caption="C# MasterDetails"
        MapRunSamplePath=true
        runat="server" />
    </template>
    
    <template name="VBTemplate">
        <Acme:SourceRef 
        RunSample="/quickstart/winforms/Samples/VB/Data/MasterDetails" 
        ViewSource="/quickstart/winforms/Samples/VB/Data/MasterDetails/MasterDetails.src"
        Icon = "/quickstart/winforms/images/wflink.jpg"
        Caption="VB MasterDetails"
        MapRunSamplePath=true
        runat="server" />
    </template>
    
</Code:CodeSnippet>

<a name="Customer Details Form">
<h5>Customer Details Form</h5>

<p>This sample demonstrates the following:

<ul> 
<li>Writing a Web Service that fills a DataSet and returns it.</li>
<li>Writing a Web Service that saves the updates in a DataSet back to the database.</li>
<li>Binding to that DataSet.</li>
<li>Updating the DataSet and tracking changes in the Form</li>
<li>Extracting changed rows from the DataSet and sending them to the Update Web Service.</li>
<li>Reconciling the saved rows and displaying errors.</li>
</ul> 

<p>To view and run this sample:
<br><br>
<Code:CodeSnippet runat=server>
    
    <template name="CsTemplate">
        <Acme:SourceRef 
        RunSample="/quickstart/winforms/Samples/Cs/Data/Update" 
        ViewSource="/quickstart/winforms/Samples/Cs/Data/Update/Update.src"
        Icon = "/quickstart/winforms/images/wflink.jpg"
        Caption="C# Customer Details Form"
        MapRunSamplePath=true
        runat="server" />
    </template>
    
    <template name="VBTemplate">
        <Acme:SourceRef 
        RunSample="/quickstart/winforms/Samples/VB/Data/Update" 
        ViewSource="/quickstart/winforms/Samples/VB/Data/Update/Update.src"
        Icon = "/quickstart/winforms/images/wflink.jpg"
        Caption="VB Customer Details Form"
        MapRunSamplePath=true
        runat="server" />
    </template>
    
</Code:CodeSnippet>



<!-- #include virtual="/quickstart/winforms/include/footer.inc" -->
