<!-- #include virtual="/quickstart/winforms/include/header.inc" -->

      <H4>Dynamic Layout in Win Forms</H4>
      <P>The controls on a Form can be dynamically resized as the Form 
      resizes.</P>
      <P>Win Forms provides&nbsp; three ways to control the layout of your Form:</P>
      <UL>
        <LI>Anchoring 
        <LI>Docking 
        <LI>Custom </LI></UL>
        
        <!-- --------------------------- ANCHORING ----------------------------- -->
      <H5>Anchoring</H5>
      <P>When a control is anchored to an edge of its container, the distance 
      between the control and the specified edge remains constant when the 
      container resizes. If a control is anchored to the right edge of its 
      container, the distance between the right edge of the control and the 
      right edge of the container remains constant when the container resizes. A 
      control can be anchored to any combination of the edges of a control. If 
      the control is anchored to opposite edges of its container (for example, 
      to the top and bottom), it resizes when the container resizes. 
      <P>For example, if you anchor a TextBox control to the left and right 
      sides of a Form, then as the Form is resized the width of the TextBox will 
      change.</P>
      <P>The following code anchors a TextBox to the top, left and right sides 
      of it container:</P>

<Code:CodeSnippet runat=server>

<template name="CsTemplate">
    <xmp class=code1>
    
        textBox1.Anchor = AnchorStyles.TopLeftRight;
    </xmp>
</template>

<template name="VBTemplate">
   <xmp class=code1>
    
        textBox1.Anchor = AnchorStyles.TopLeftRight
   </xmp>
</template>

</Code:CodeSnippet>

<p>To view and run this sample:
<br><br>
<Code:CodeSnippet runat=server>
    
    <template name="CsTemplate">
        <Acme:SourceRef 
        RunSample="/quickstart/winforms/Samples/Cs/Layout/Anchoring" 
        ViewSource="/quickstart/winforms/Samples/Cs/Layout/Anchoring/Anchoring.src"
        Icon = "/quickstart/winforms/images/wflink.jpg"
        Caption="C# Anchoring"
        MapRunSamplePath=true
        runat="server" />
    </template>
    
    <template name="VBTemplate">
        <Acme:SourceRef 
        RunSample="/quickstart/winforms/Samples/VB/Layout/Anchoring" 
        ViewSource="/quickstart/winforms/Samples/VB/Layout/Anchoring/Anchoring.src"
        Icon = "/quickstart/winforms/images/wflink.jpg"
        Caption="VB Anchoring"
        MapRunSamplePath=true
        runat="server" />
    </template>
    
</Code:CodeSnippet>


<!-- --------------------------- DOCKING ----------------------------- -->

<h5>Docking</h5> 

<P>When a control is docked to the edge of its container, it remains in 
contact with that edge when the container resizes.  For example, Windows 
Explorer docks its TreeView control to the left side of the window and its 
ListView control to the right side of the window.  If multiple controls 
are docked to one edge, one is docked to the edge of the container, and 
the others are docked as close as possible to the edge without covering 
each other.</P> 
      
<P>The following code docks a Panel to the Left of a its container:</P> 

<Code:CodeSnippet runat=server>
<template name="CsTemplate">
    <xmp class=code1>
    
       Panel1.Dock = DockStyle.Left;
    </xmp>
</template>
<template name="VBTemplate">
   <xmp class=code1>
       
       Panel1.Dock = DockStyle.Left
   </xmp>
</template>
</Code:CodeSnippet>

<p>To view and run this sample:
<br><br>
<Code:CodeSnippet runat=server>
    
    <template name="CsTemplate">
        <Acme:SourceRef 
        RunSample="/quickstart/winforms/Samples/Cs/Layout/Docking" 
        ViewSource="/quickstart/winforms/Samples/Cs/Layout/Docking/Docking.src"
        Icon = "/quickstart/winforms/images/wflink.jpg"
        Caption="C# Docking"
        MapRunSamplePath=true
        runat="server" />
    </template>
    
    <template name="VBTemplate">
        <Acme:SourceRef 
        RunSample="/quickstart/winforms/Samples/VB/Layout/Docking" 
        ViewSource="/quickstart/winforms/Samples/VB/Layout/Docking/Docking.src"
        Icon = "/quickstart/winforms/images/wflink.jpg"
        Caption="VB Docking"
        MapRunSamplePath=true
        runat="server" />
    </template>
    
</Code:CodeSnippet>

<!-- --------------------------- DockMan ----------------------------- -->

<h5>DockMan Sample</h5>

<P>The following sample allows you to manipulate the anchoring and docking 
properties of a Button at runtime so that you can understand how they 
interact.</P> 
      
<Code:CodeSnippet runat=server> 
    
    <template name="CsTemplate">
        <Acme:SourceRef 
        RunSample="/quickstart/winforms/Samples/Cs/Layout/Dockman" 
        ViewSource="/quickstart/winforms/Samples/Cs/Layout/Dockman/Dockman.src"
        Icon = "/quickstart/winforms/images/wflink.jpg"
        Caption="C# Dockman"
        MapRunSamplePath=true
        runat="server" />
    </template>
    
    <template name="VBTemplate">
        <Acme:SourceRef 
        RunSample="/quickstart/winforms/Samples/VB/Layout/Dockman" 
        ViewSource="/quickstart/winforms/Samples/VB/Layout/Dockman/Dockman.src"
        Icon = "/quickstart/winforms/images/wflink.jpg"
        Caption="VB Dockman"
        MapRunSamplePath=true
        runat="server" />
    </template>
    
</Code:CodeSnippet>

<h5>Custom Layout</h5>

<P>You can write your own Layout manager using the Layout event exposed on 
the Control class.  This event is raised whenever any event occurs that 
would cause the control to layout child controls.  These events include 
resize, show/hide child controls, add/remove child controls.  This event 
should be used to perform any custom layout logic.</P> 


<!-- #include virtual="/quickstart/winforms/include/footer.inc" -->
