<!-- #include virtual="/quickstart/winforms/include/header.inc" -->

<h4>Creating Multiple Document Interface Win Forms Applications</h4>

<P>Multiple Document Interface (MDI) applications have a single primary 
window (the parent window) that visually contains a set of windows within 
its client region (child windows).  Each child window is a form that is 
constrained to appear only within the parent not the entire desktop.  
Children typically share the menu bar, tool bar, and other parts of the 
parent's interface.  Secondary windows like dialog boxes are not 
constrained to the parent window's client region.</P> 

<h5>Creating and MDI application</h5>

 <P>You can create an MDI application by following these steps:
 <ol>
 <LI>Create a Form (MainForm) that represents the MDI parent window and 
 set its IsMDIContainer property to true. The following code demonstrates
 how to set this property: <BR><BR>

<Code:CodeSnippet runat=server>
<template name="CsTemplate">
    <xmp class=code1>
    
    this.IsMDIContainer = true;
    </xmp>
</template>

<template name="VBTemplate">
   <xmp class=code1>
    
    Me.IsMDIContainer = True
   </xmp>
</template>
</Code:CodeSnippet>
<br>

      
<LI>Create child forms and set the MDI Parent property of each form to 
reference the parent form. The following code demonstrates setting the
  MDI parent for an instance of a child form: <BR><BR>
          
<Code:CodeSnippet runat=server>
<template name="CsTemplate">
    <xmp class=code1>
    
    doc.MDIParent = this;
    </xmp>
</template>

<template name="VBTemplate">
   <xmp class=code1>
    
    doc.MDIParent = Me
   </xmp>
</template>
</Code:CodeSnippet>
<br>
</ul>

<P>If you have different types of data to display, you can have multiple 
types of child forms.  To display a child form, create an instance of the 
child form and call its Show method.</P> 
      
<H5>Standard MDI menus</H5> 
      
<P>Typically an MDI application has a <B>Windows</B> menu that allows the 
user to arrange the open child windows by tiling and cascading.  The 
Windows menu also allows you to navigate to any of the open child windows.  
To create a Windows menu add the menu items for tiling and cascading to a 
Windows menu in your main form and set the MDIList property to true for 
the top level Windows menu.  The following code demonstrates how to create 
a Windows menu in an MDI application: </P> 

<Code:CodeSnippet runat=server>
<template name="CsTemplate">
    <xmp class=code1>
        
    ....
    
    //Add Window Menu</span>
    MenuItem miWindow = mainMenu.MenuItems.Add("&Window");
    miWindow.MenuItems.Add("&Cascade", new EventHandler(this.WindowCascade_Clicked));
    miWindow.MenuItems.Add("&Tile Horizontal", new EventHandler(this.WindowTileH_Clicked));
    miWindow.MenuItems.Add("&Tile Vertical", new EventHandler(this.WindowTileV_Clicked));
    miWindow.MDIList = true ; //Adds the MDI Window List to the bottom of the menu</span>

    ....
    
    private void WindowCascade_Clicked(object sender, System.EventArgs e) {
        this.LayoutMDI(MDILayout.Cascade);   
    }

    private void WindowTileH_Clicked(object sender, System.EventArgs e) {
        this.LayoutMDI(MDILayout.TileHorizontal);
    }

    private void WindowTileV_Clicked(object sender, System.EventArgs e) {
        this.LayoutMDI(MDILayout.TileVertical);
    }
    
    ....

    </xmp>
</template>

<template name="VBTemplate">
   <xmp class=code1>

    ....
    'Add Window Menu
    Dim miWindow As MenuItem = mainMenu.MenuItems.Add("&Window")
    miWindow.MenuItems.Add("&Cascade", AddressOf Me.WindowCascade_Clicked)
    miWindow.MenuItems.Add("&Tile Horizontal", AddressOf Me.WindowTileH_Clicked)
    miWindow.MenuItems.Add("&Tile Vertical", AddressOf Me.WindowTileV_Clicked)
    miWindow.MDIList = true  'Adds the AxHosting Window List to the bottom of the menu
    ....
    'Window->Cascade Menu item handler
    Private Sub WindowCascade_Clicked(sender As object, e As System.EventArgs)
        Me.LayoutMDI(MDILayout.Cascade)   
    End Sub


    'Window->Tile Horizontally Menu item handler
    Private Sub WindowTileH_Clicked(sender As object, e As System.EventArgs)
        Me.LayoutMDI(MDILayout.TileHorizontal)
    End Sub


    'Window->Tile Vertically Menu item handler
    Private Sub WindowTileV_Clicked(sender As object, e As System.EventArgs)
        Me.LayoutMDI(MDILayout.TileVertical)
    End Sub
    ....

   </xmp>
</template>
</Code:CodeSnippet>
<br>

<h5>Child Window Activation</h5>

<P>If you want your parent form to be notified when a child window is 
activated by the user you can register an event-handling method for the 
<B>MDIChildActivate</B> event.  You can determine which child window is 
active using the <B>ActiveMDIChild</B> property of the Form class.  For 
example, the following code updates a <b>StatusBar</b> control on the 
parent form with the name of the child window:</P>

<Code:CodeSnippet runat=server>
<template name="CsTemplate">
    <xmp class=code1>
        
    ....
    
    this.AddOnMDIChildActivate(new EventHandler(this.MDIChildActivated));

    ....
    
    private void MDIChildActivated(object sender, System.EventArgs e) {
        statusBar1.Text = this.ActiveMDIChild.Text;
    }
    
    ....

    </xmp>
</template>

<template name="VBTemplate">
   <xmp class=code1>
        
    ....
    
    Me.AddOnMDIChildActivate(AddressOf Me.MDIChildActivated)

    ....
    
    Private Sub MDIChildActivated(sender As object, e As System.EventArgs)
        If (Me.ActiveMDIChild <> Nothing) Then
            statusBar1.Text = Me.ActiveMDIChild.Text
        End If 
    End Sub

    
    ....

   </xmp>
</template>
</Code:CodeSnippet>
<br>


<h5>Menu Merging</h5>

<P>If a child window has a set of menu items that should appear in the 
parent window's main menu, you can create a <b> MainMenu</b> as part of 
the child window form.  When the child window is activated, its MainMenu 
will be merged with the MainMenu of the parent window.  For example, the 
following code creates a &quot;Format&quot; menu item for each child 
window:</P> 
      
<Code:CodeSnippet runat=server>
<template name="CsTemplate">
    <xmp class=code1>
        
    ....
    MainMenu mainMenu = new MainMenu();
    this.Menu = mainMenu;

    //Add Formatting Menu</span>
    MenuItem miFormat = mainMenu.MenuItems.Add("F&ormat (" + docName + ")");
    miFormat.MergeType = MenuMerge.Add ;

    //Font Face sub-menu</span>
    MenuItem miArial = new MenuItem("&Arial", new EventHandler(this.FormatFont_Clicked));
    MenuItem miTimesNewRoman = new MenuItem("&Times New Roman", new EventHandler(this.FormatFont_Clicked));
    MenuItem miTahoma = new MenuItem("&Courier New", new EventHandler(this.FormatFont_Clicked));
    miArial.Checked = true ;
    miFormatFontChecked = miArial ;
    miArial.DefaultItem = true ;

    miFormat.MenuItems.Add( "Font &Face"
              , new EventHandler(this.FormatFont_Clicked)  
              , (new MenuItem[]{ miArial, miTimesNewRoman, miTahoma })
              );

    ....
    
    </xmp>
</template>

<template name="VBTemplate">
   <xmp class=code1>

    ....
   
     'Add Formatting Menu
     Dim miFormat As MenuItem = mainMenu.MenuItems.Add("F&ormat (" + docName + ")")
     miFormat.MergeType = MenuMerge.Add

     'Font Face sub-menu
     Dim miArial As MenuItem  = new MenuItem("&Arial", AddressOf Me.FormatFont_Clicked)
     Dim miTimesNewRoman As MenuItem  = new MenuItem("&Times New Roman", AddressOf Me.FormatFont_Clicked)
     Dim miCourier As MenuItem = new MenuItem("&Courier New", AddressOf Me.FormatFont_Clicked)
     miArial.Checked = true 
     miFormatFontChecked = miArial 
     miArial.DefaultItem = true 

     miFormat.MenuItems.Add( "Font &Face" _
               , new EventHandler(AddressOf Me.FormatFont_Clicked)  _
               , (new MenuItem() {miArial, miTimesNewRoman, miCourier }))
    ....

   </xmp>
</template>
</Code:CodeSnippet>
<br>

<P>By default the child window menu is added to the parent window.  You 
can control how the merge occurs using the <B>MergeOrder</B> and 
<B>MergeType</B> properties.  For example, the following code creates a 
child window File menu item that is merged with the parent window File 
menu item:</P> 
      

<Code:CodeSnippet runat=server>
<template name="CsTemplate">
    <xmp class=code1>
        
    ....
    
    Parent Form:

        //Add File Menu
        MenuItem miFile = mainMenu.MenuItems.Add("&File");
        miFile.MergeOrder=0;
        miFile.MergeType = MenuMerge.MergeItems;
        
        MenuItem miAddDoc = new MenuItem("&Add Document", new EventHandler(this.FileAdd_Clicked), Shortcut.CtrlA);
        miAddDoc.MergeOrder=100;

        MenuItem miExit = new MenuItem("E&xit", new EventHandler(this.FileExit_Clicked), Shortcut.CtrlX);
        miExit.MergeOrder=110;

        miFile.MenuItems.Add(miAddDoc);
        miFile.MenuItems.Add("-");     // Gives us a seperator
        miFile.MenuItems.Add(miExit);

    ....
    
    Child Form:
    
        //Add File Menu
        MenuItem miFile = mainMenu.MenuItems.Add("&File");
        miFile.MergeType = MenuMerge.MergeItems;
        miFile.MergeOrder = 0;
        
        MenuItem miLoadDoc = miFile.MenuItems.Add("&Load Document (" + docName + ")");
        miLoadDoc.MergeOrder = 105;
    ....

    
    </xmp>
</template>

<template name="VBTemplate">
   <xmp class=code1>

    ....
    
    Parent Form:

        'Add File Menu
        Dim miFile As MenuItem = mainMenu.MenuItems.Add("&File")
        miFile.MergeOrder=0
        miFile.MergeType = MenuMerge.MergeItems
        
        Dim miAddDoc As MenuItem = new MenuItem("&Add Document", new EventHandler(AddressOf Me.FileAdd_Clicked), Shortcut.CtrlA)
        miAddDoc.MergeOrder=100

        Dim miExit As MenuItem = new MenuItem("E&xit", new EventHandler(AddressOf Me.FileExit_Clicked), Shortcut.CtrlX)
        miExit.MergeOrder=110

        miFile.MenuItems.Add(miAddDoc)
        miFile.MenuItems.Add("-")     ' Gives us a seperator
        miFile.MenuItems.Add(miExit)

    ....
    
    Child Form:

        'Add File Menu
        Dim miFile As MenuItem = mainMenu.MenuItems.Add("&File")
        miFile.MergeType = MenuMerge.MergeItems
        miFile.MergeOrder = 0
        
        Dim miLoadDoc As MenuItem = miFile.MenuItems.Add("&Load Document (" + docName + ")")
        miLoadDoc.MergeOrder = 105
    
    ....
    
   </xmp>
</template>
</Code:CodeSnippet>
<br>


<h5>A simple MDI application</h5>
<P>The following sample illustrates the features mentioned previously.
<br><br>

<p>To view and run this sample:
<br><br>
<Code:CodeSnippet runat=server>
    
    <template name="CsTemplate">
        <Acme:SourceRef 
        RunSample="/quickstart/winforms/Samples/Cs/MDI" 
        ViewSource="/quickstart/winforms/Samples/Cs/MDI/MDI.src"
        Icon = "/quickstart/winforms/images/wflink.jpg"
        Caption="C# MDI Apps"
        MapRunSamplePath=true
        runat="server" />
    </template>
    
    <template name="VBTemplate">
        <Acme:SourceRef 
        RunSample="/quickstart/winforms/Samples/VB/MDI" 
        ViewSource="/quickstart/winforms/Samples/VB/MDI/MDI.src"
        Icon = "/quickstart/winforms/images/wflink.jpg"
        Caption="VB MDI Apps"
        MapRunSamplePath=true
        runat="server" />
    </template>
    
</Code:CodeSnippet>

<!-- #include virtual="/quickstart/winforms/include/footer.inc" -->
