<!-- #include virtual="/quickstart/winforms/include/header.inc" -->

      <H4>Making Your Win Forms Applications Accessible to People with
      Disabilities</H4>
      <P>Microsoft Active Accessibility (MSAA) is a technology that makes 
      computer programs more accessible to people who use accessibility aids. 
      For developers, it also can expand the capabilities of testing tools and 
      other specialized utilities. Detailed information on MSAA can be found at
      MSAA web 
      site.</P>
      <H5>What Does Active Accessibility Do?</H5>
      <P>Active Accessibility provides a standard way for accessibility aids to 
      get information about user interface elements, and for programs to expose 
      that information to the aids. For example, Active Accessibility provides 
      these individual pieces of information: 
      <UL>
        <LI>Type of object 
        <LI>Name of object 
        <LI>Location of object 
        <LI>Current state of object </LI></UL>
      <P>And, it provides: 
      <UL>
        <LI>Notification of changes in user interface via windows Events, and 
        Navigation (spatial and logical) 
        <LI>This standard helps program-developers and aid-developers alike 
        ensure their products are compatible. </LI></UL>
      <H5>How Does Win Form Help?</H5>
      <P>MSAA defines an interface call IAccessible. This interface the 
      mechanism through which information is provided to accessibility aids. 
      WinForms implements this interface for all of its controls, and exposes a 
      set of accessibility properties on each control that can simply and easily 
      be set at design time or runtime. This makes it much easier to build 
      accessible applications. The properties are: 
      <UL>
        <LI><B>AccessibleName: </B>The name of the control - for example 
        "SaveButton" 
        <LI><B>AccessibleDescription: </B>A description of the purpose of the control - 
        for example "Press this button to save the customer" 
        <LI><B>AccessibleRole: </B>The role of the control - for example 
        AcessibleRoles.PushButton </LI></UL>
      <P>Win Forms also maps other properties to their appropriate IAccessible 
      properties - for instance the HelpProvider property.</P>
      <P>The following code shows how to set the AccessibleName and 
      AccessibleDescription properties on a TextBox</P>
      
<Code:CodeSnippet runat=server>

<template name="CsTemplate">
    <xmp class=code1>
		
      textBox1.Location = new System.Drawing.Point(16, 24);
      textBox1.Text = "Hello Win Forms World";
      textBox1.AccessibleName = "TextEntryField";
      textBox1.TabIndex = 0;
      textBox1.AccessibleDescription = "Please enter some text in the box";
      textBox1.Size = new System.Drawing.Size(360, 20);
    </xmp>
</template>

<template name="VBTemplate">
   <xmp class=code1>

      textBox1.Location = new System.Drawing.Point(16, 24)
      textBox1.Text = "Hello Win Forms World"
      textBox1.AccessibleName = "TextEntryField"
      textBox1.TabIndex = 0
      textBox1.AccessibleDescription = "Please enter some text in the box"
      textBox1.Size = new System.Drawing.Size(360, 20)
   
   </xmp>
</template>

</Code:CodeSnippet>

<p>To view and run this sample:
<br><br>
<Code:CodeSnippet runat=server>
    
    <template name="CsTemplate">
        <Acme:SourceRef 
        RunSample="/quickstart/winforms/Samples/Cs/Accessible" 
        ViewSource="/quickstart/winforms/Samples/Cs/Accessible/Accessible.src"
        Icon = "/quickstart/winforms/images/wflink.jpg"
        Caption="C# Accessible"
        MapRunSamplePath=true
        runat="server" />
    </template>
    
    <template name="VBTemplate">
        <Acme:SourceRef 
        RunSample="/quickstart/winforms/Samples/VB/Accessible" 
        ViewSource="/quickstart/winforms/Samples/VB/Accessible/Accessible.src"
        Icon = "/quickstart/winforms/images/wflink.jpg"
        Caption="VB Accessible"
        MapRunSamplePath=true
        runat="server" />
    </template>
    
</Code:CodeSnippet>

<!-- #include virtual="/quickstart/winforms/include/footer.inc" -->
