//------------------------------------------------------------------------------
/// <copyright from='1997' to='2001' company='Microsoft Corporation'>           
///    Copyright (c) Microsoft Corporation. All Rights Reserved.                
///       
///    This source code is intended only as a supplement to Microsoft
///    Development Tools and/or on-line documentation.  See these other
///    materials for detailed information regarding Microsoft code samples.
///
/// </copyright>                                                                
//------------------------------------------------------------------------------
namespace Microsoft.Samples.WinForms.Cs.ComboBoxCtl {
    using System;
    using System.ComponentModel;
    using System.Collections;
    using System.WinForms;
    using System.Resources;
    using System.Drawing;
    using System.Drawing.Drawing2D;

    // <doc>
    // <desc>
    //     This sample demonstrates the properties and features
    //     of the ComboBox control.
    //     The sample also shows two different ways to use a ComboBox which does
    //     not contain String data.  The first method uses a Hashtable which maps
    //     strings to the data and the second method uses a wrapper object which
    //     exposes a toString() method used by the ComboBox.
    // </desc>
    // </doc>
    //
    public class ComboBoxCtl : System.WinForms.Form {
        private System.ComponentModel.Container components;
        private System.WinForms.ComboBox comboBegin;
        private System.WinForms.CheckBox chkEnabled;
        private System.WinForms.CheckBox chkSorted;
        private System.WinForms.CheckBox chkIntegralHeight;
        private System.WinForms.Label label1;
        private System.WinForms.Label label2;
        private System.WinForms.Label label3;
        private System.WinForms.Label label4;
        private System.WinForms.ComboBox cmbMaxDropDownItems;
        private System.WinForms.ComboBox cmbItemHeight;
        private System.WinForms.ComboBox cmbDrawMode;
        private System.WinForms.ComboBox cmbStyle;
        private System.WinForms.ComboBox comboEnd;
        private System.WinForms.GroupBox groupBox1;
        private System.WinForms.Panel panel1;
        private System.WinForms.Label label6; 
        private System.WinForms.Label label7; 
        private System.WinForms.Label label5; 
        private System.WinForms.Label label8; 
        private System.WinForms.Label label9; 
        private System.WinForms.ToolTip toolTip1;
    
        private Size      cmbsize ;
        private Hashtable colorMap = new Hashtable();
        private Color     gradientBegin = Color.Red;
        private Color     gradientEnd = Color.Blue;

        // <doc>
        // <desc>
        //     We speed up ownerdraw operations on the Color ComboBoxes
        //     by caching the Brush objects which represent the Color
        //     to choose.
        // </desc>
        // <seealso class='ComboBoxCtl.GetTheBrush()'/>
        // </doc>
        //
        private Hashtable brushMap = new Hashtable();

        // <doc>
        // <desc>
        //     Public Constructor
        // </desc>
        // </doc>
        //
        public ComboBoxCtl () : base() {
             	
            // This call is required for support of the Win Forms Form Designer.
            InitializeComponent();

            InitControlState();
            MakeColorMap();
            FillItems(comboBegin);
            comboBegin.SelectedIndex = 0;
            FillItems(comboEnd);
            comboEnd.SelectedIndex = comboEnd.Items.Count-1;
            cmbsize = comboBegin.Size;
        }

        // <doc>
        // <desc>
        //     This class defines the objects in the ComboBoxes that drive
        //     the properties of the color selection ComboBoxes.
        //     Use this object to use erations with ComboBoxes and ListBoxes.
        //     Add the <paramref term='s'/> data member to the eration item's
        //     english description and the <paramref term='i'/> data member to the actual
        //     value of the eration item.
        //     The ToString() method will allow the ComboBox and ListBox controls to 
        //     display the text which represents the eration item.
        // </desc>
        // </doc>
        //
        private class StringIntObject {
            public string s;
            public int i;

            public StringIntObject(string sz, int n) {
                s=sz;
                i=n;
            }

            public override string ToString() {
                return s;
            }
        }

        // <doc>
        // <desc>
        //     Sets the default states for the controls driving the properties
        //     of the two ComboBoxes.
        // </desc>
        // </doc>
        //
        private void InitControlState() {
            // Sync the checkboxes
            chkSorted.Checked = comboBegin.Sorted;
            chkEnabled.Checked = comboBegin.Enabled;
            chkIntegralHeight.Checked = comboBegin.IntegralHeight;

            // Sync ComboBox styles to ComboBoxStyle.DROPDOWN
            StringIntObject[] aStyle = new StringIntObject[3];
            aStyle[0] = new StringIntObject("Simple",(int)ComboBoxStyle.Simple);
            aStyle[1] = new StringIntObject("Dropdown",(int)ComboBoxStyle.DropDown);
            aStyle[2] = new StringIntObject("Dropdownlist",(int)ComboBoxStyle.DropDownList);
            cmbStyle.Items.All = aStyle;
            comboBegin.Style = (ComboBoxStyle)aStyle[1].i;
            comboEnd.Style = (ComboBoxStyle)aStyle[1].i;
            cmbStyle.SelectedIndex = 1;

            // Sync ComboBox draw modes to DrawMode.NORMAL
            StringIntObject[] aDMO = new StringIntObject[3];
            aDMO[0] = new StringIntObject("Normal",(int)DrawMode.Normal);
            aDMO[1] = new StringIntObject("Ownerdrawfixed",(int)DrawMode.OwnerDrawFixed);
            aDMO[2] = new StringIntObject("Ownerdrawvariable",(int)DrawMode.OwnerDrawVariable);
            cmbDrawMode.Items.All = aDMO;
            comboBegin.DrawMode = (DrawMode)aDMO[0].i;
            comboEnd.DrawMode = (DrawMode)aDMO[0].i;
            cmbDrawMode.SelectedIndex = 0;
        }

        private void FillItems(ComboBox cmb) {
            IEnumerator keys = colorMap.Keys.GetEnumerator();
            while (keys.MoveNext()) {
                cmb.Items.Add(keys.Current);
            }
        }

        private void MakeColorMap() {
            colorMap["Aqua"] = Color.Aqua;
            colorMap["Black"] = Color.Black;
            colorMap["Blue"] = Color.Blue;
            colorMap["Brown"] = Color.Brown;
            colorMap["Cyan"] = Color.Cyan;
            colorMap["Dark Gray"] = Color.DarkGray;
            colorMap["Gray"] = Color.Gray;
            colorMap["Green"] = Color.Green;
            colorMap["Light Gray"] = Color.LightGray;
            colorMap["Magenta"] = Color.Magenta;
            colorMap["Orange"] = Color.Orange;
            colorMap["Purple"] = Color.Purple;
            colorMap["Red"] = Color.Red;
            colorMap["White"] = Color.White;
            colorMap["Yellow"] = Color.Yellow;
        }

        // <doc>
        // <desc>
        //     ComboBoxCtl overrides dispose so it can clean up the
        //     component list.
        // </desc>
        // </doc>
        //
        public override void Dispose() {
            base.Dispose();
            components.Dispose();
        }

        // <doc>
        // <desc>
        //     Returns the int which is currently selected in a ComboBox.
        // </desc>
        // <param term='cmb'>
        //     The ComboBox to get the integral value from
        // </param>
        // <retvalue>
        //     If the String is in a valid numeric format, the integer
        //     representation of it is returned.  Otherwise, if
        //     no item is selected <it>or</it> the selected item is
        //     not a valid int, -1 is returned.
        // </retvalue>
        // </doc>
        //
        private int SelectedValue(ComboBox cmb) {
            int ret;
            object obj = cmb.SelectedItem;
            if (obj == null) {
                return -1;
            }
            try {
                ret = Int32.FromString(obj.ToString());
            }
            catch (FormatException) {
                return -1;
            }
            return ret;
        }

        private void chkEnabled_Click(object sender, EventArgs e) {
            comboBegin.Enabled = chkEnabled.Checked;
            comboEnd.Enabled = chkEnabled.Checked;
        }

        private void chkIntegralHeight_Click(object sender, EventArgs e) {
            comboBegin.IntegralHeight = chkIntegralHeight.Checked;
            comboEnd.IntegralHeight = chkIntegralHeight.Checked;
        }

        private void chkSorted_Click(object sender, EventArgs e) {
            bool sorted = chkSorted.Checked;
            comboBegin.Sorted = sorted;
            comboEnd.Sorted = sorted;
            if (!sorted) {
                RandomShuffle(comboBegin);
                RandomShuffle(comboEnd);
            }
        }

        // <doc>
        // <desc>
        //     Performs a random shuffle on the given ComboBox.
        // </desc>
        // <param term='cmb'>
        //     The ComboBox to shuffle
        // </param>
        // </doc>
        //
        private void RandomShuffle(ComboBox cmb) {
            object [] items = cmb.Items.All;
            int swapItem;
            Random rand = new Random();
            for (int i = 0; i < items.Length; ++i) {
                swapItem = Math.Abs(rand.Next()) % items.Length;
                if (swapItem != i) {
                    object tempObject = items[swapItem];
                    items[swapItem] = items[i];
                    items[i] = tempObject;
                }
            }
            cmb.Items.All = items;
        }

        private void cmbItemHeight_SelectedIndexChanged(object sender, EventArgs e) {
            int i = SelectedValue(cmbItemHeight);
            if (i == -1)
                return;
            comboBegin.ItemHeight = i;
            comboEnd.ItemHeight = i;
        }

        private void cmbStyle_SelectedIndexChanged(object sender, EventArgs e) {
            ComboBoxStyle i = (ComboBoxStyle)(((StringIntObject)cmbStyle.SelectedItem).i);
            comboBegin.Style = i;
            comboEnd.Style = i;

            if (i == ComboBoxStyle.Simple) {
                comboBegin.SetSize(cmbsize.Width, cmbsize.Height * 3);
                comboEnd.SetSize(cmbsize.Width, cmbsize.Height * 3);
                cmbMaxDropDownItems.Enabled = false;
            }
        }

        private void cmbDrawMode_SelectedIndexChanged(object sender, EventArgs e) {
            DrawMode i = (DrawMode)(((StringIntObject)cmbDrawMode.SelectedItem).i);
            comboBegin.DrawMode = i;
            comboEnd.DrawMode = i;

            if (i == DrawMode.OwnerDrawFixed) {
                cmbItemHeight.Enabled = true;
            }
            else {
                cmbItemHeight.Enabled = false;
            }
        }

        // <doc>
        // <desc>
        //     This DrawItem event handler is invoked to draw an item in a ComboBox if that
        //     ComboBox is in an OwnerDraw DrawMode.
        // </desc>
        // </doc>
        //
        private void combo_DrawItem(object sender, DrawItemEventArgs die) {
            ComboBox cmb = (ComboBox) sender;
            if (die.Index == -1)
                return;
            if (sender == null)
                return;

            string strColor = (string)cmb.Items[die.Index];
            Color clrSelected = (Color)colorMap[strColor];
            Graphics g = die.Graphics;

            // If the item is selected, this draws the correct background color
            die.DrawBackground();
            die.DrawFocusRectangle();

            // Draw the color's preview box
            Rectangle rectPreviewBox = die.Bounds;
            rectPreviewBox.Offset(2,2);
            rectPreviewBox.Width = 20;
            rectPreviewBox.Height -= 4;
            g.DrawRectangle(new Pen(die.ForeColor), rectPreviewBox);

            /*
             * Get the appropriate Brush object for the selected color
             * and fill the preview box.
             */
            Brush coloredBrush = GetTheBrush(clrSelected);
            rectPreviewBox.Offset(1,1);
            rectPreviewBox.Width -= 2;
            rectPreviewBox.Height -= 2;
            g.FillRectangle(coloredBrush, rectPreviewBox);

            // Draw the name of the color selected
            g.DrawString(strColor, Font, new SolidBrush(die.ForeColor), die.Bounds.X+30,die.Bounds.Y+1);

            g.Dispose();
        }

        // <doc>
        // <desc>
        //     Retrieves a Brush object which corresponds to <em>clr</em>
        //     Brushes created are cached for performance.
        // </desc>
        // <param term='clr'>
        //     The Color which the returned Brush will paint
        // </param>
        // <retvalue>
        //     A Brush object which corresponds to <em>clr</em>
        //     Treat this object as read-only.
        // </retvalue>
        // </doc>
        //
        private Brush GetTheBrush(Color clr) {
            if (clr.IsEmpty)
                throw new ArgumentException();
            object ret = brushMap[clr];
            if (ret == null) {
                Brush clrBrush = new SolidBrush(clr);
                brushMap.Add(clr,clrBrush);
                return clrBrush;
            }
            else {
                return(Brush)ret;
            }
        }

        private void comboBegin_SelectedIndexChanged(object sender, EventArgs e) {
            Color c = (Color)colorMap[comboBegin.SelectedItem];
            gradientBegin = c;
            panel1.Invalidate();
        }

        private void comboEnd_SelectedIndexChanged(object sender, EventArgs e) {
            Color c = (Color)colorMap[comboEnd.SelectedItem];
            gradientEnd = c;
            panel1.Invalidate();
        }

        private void cmbMaxDropDownItems_SelectedIndexChanged(object sender, EventArgs e) {
            int i = SelectedValue(cmbMaxDropDownItems);
            if (i == -1)
                return;
            comboBegin.MaxDropDownItems = i;
            comboEnd.MaxDropDownItems = i;
        }

        private void combo_MeasureItem(object sender, MeasureItemEventArgs mie) {
            mie.ItemHeight = (mie.Index % 6) + 12;
        }

        private void panel1_Paint(object sender, PaintEventArgs e) {
            Brush brush = new LinearGradientBrush (panel1.ClientRectangle, gradientBegin, gradientEnd,LinearGradientMode.ForwardDiagonal) ;
            e.Graphics.FillRectangle(brush, panel1.ClientRectangle);
        }

        private void combo_KeyPress(object sender, KeyPressEventArgs e) {
            if (Char.IsLetterOrDigit(e.KeyChar))
                e.Handled = true;
        }


        // NOTE: The following code is required by the Win Forms Form Designer
        // It can be modified using the Win Forms Form Designer.  
        // Do not modify it using the code editor.
        private void InitializeComponent() {
            this.components = new System.ComponentModel.Container();
            this.groupBox1 = new System.WinForms.GroupBox();
            this.comboBegin = new System.WinForms.ComboBox();
            this.chkEnabled = new System.WinForms.CheckBox();
            this.chkSorted = new System.WinForms.CheckBox();
            this.chkIntegralHeight = new System.WinForms.CheckBox();
            this.label1 = new System.WinForms.Label();
            this.label2 = new System.WinForms.Label();
            this.label3 = new System.WinForms.Label();
            this.label4 = new System.WinForms.Label();
            this.cmbMaxDropDownItems = new System.WinForms.ComboBox();
            this.cmbItemHeight = new System.WinForms.ComboBox();
            this.cmbDrawMode = new System.WinForms.ComboBox();
            this.cmbStyle = new System.WinForms.ComboBox();
            this.comboEnd = new System.WinForms.ComboBox();
            this.panel1 = new System.WinForms.Panel();
            this.label6 = new System.WinForms.Label();
            this.label7 = new System.WinForms.Label();
            this.label5 = new System.WinForms.Label();
            this.label8 = new System.WinForms.Label();
            this.label9 = new System.WinForms.Label();
            this.toolTip1 = new System.WinForms.ToolTip(components);

            this.Size = new System.Drawing.Size(512, 320);
            this.Text = "ComboBox";

            groupBox1.Location = new System.Drawing.Point(248, 16);
            groupBox1.Size = new System.Drawing.Size(248, 264);
            groupBox1.TabIndex = 2;
            groupBox1.TabStop = false;
            groupBox1.Text = "ComboBox";

            comboBegin.Location = new System.Drawing.Point(24, 32);
            comboBegin.Size = new System.Drawing.Size(208, 21);
            comboBegin.TabIndex = 0;
            comboBegin.Text = "comboBegin1";
            comboBegin.Sorted = true;
            comboBegin.AddOnKeyPress(new KeyPressEventHandler(this.combo_KeyPress));
            comboBegin.AddOnDrawItem(new DrawItemEventHandler(this.combo_DrawItem));
            comboBegin.AddOnMeasureItem(new MeasureItemEventHandler(this.combo_MeasureItem));
            comboBegin.AddOnSelectedIndexChanged(new EventHandler(this.comboBegin_SelectedIndexChanged));

            chkEnabled.Location = new System.Drawing.Point(16, 24);
            chkEnabled.Size = new System.Drawing.Size(88, 16);
            chkEnabled.TabIndex = 0;
            chkEnabled.Text = "enabled";
            chkEnabled.AddOnClick(new EventHandler(this.chkEnabled_Click));

            chkSorted.Location = new System.Drawing.Point(16, 48);
            chkSorted.Size = new System.Drawing.Size(88, 16);
            chkSorted.TabIndex = 1;
            chkSorted.Text = "sorted";
            chkSorted.AddOnClick(new EventHandler(this.chkSorted_Click));

            chkIntegralHeight.Location = new System.Drawing.Point(16, 72);
            chkIntegralHeight.Size = new System.Drawing.Size(88, 16);
            chkIntegralHeight.TabIndex = 2;
            chkIntegralHeight.Text = "integralHeight";
            chkIntegralHeight.AddOnClick(new EventHandler(this.chkIntegralHeight_Click));

            label1.Location = new System.Drawing.Point(16, 104);
            label1.Size = new System.Drawing.Size(88, 16);
            label1.TabIndex = 8;
            label1.TabStop = false;
            label1.Text = "style";

            label2.Location = new System.Drawing.Point(16, 128);
            label2.Size = new System.Drawing.Size(88, 16);
            label2.TabIndex = 9;
            label2.TabStop = false;
            label2.Text = "drawMode";

            label3.Location = new System.Drawing.Point(16, 152);
            label3.Size = new System.Drawing.Size(80, 16);
            label3.TabIndex = 10;
            label3.TabStop = false;
            label3.Text = "itemHeight";

            label4.Location = new System.Drawing.Point(16, 176);
            label4.Size = new System.Drawing.Size(88, 16);
            label4.TabIndex = 11;
            label4.TabStop = false;
            label4.Text = "maxDropdownItems";

            cmbMaxDropDownItems.Location = new System.Drawing.Point(128, 168);
            cmbMaxDropDownItems.Size = new System.Drawing.Size(104, 21);
            cmbMaxDropDownItems.TabIndex = 7;
            cmbMaxDropDownItems.Text = "";
            cmbMaxDropDownItems.Style = System.WinForms.ComboBoxStyle.DropDownList;
            cmbMaxDropDownItems.Items.All = (object[])new object[] {"2", "4", "6", "8", "10"};
            cmbMaxDropDownItems.AddOnSelectedIndexChanged(new EventHandler(this.cmbMaxDropDownItems_SelectedIndexChanged));

            cmbItemHeight.Location = new System.Drawing.Point(128, 144);
            cmbItemHeight.Size = new System.Drawing.Size(104, 21);
            cmbItemHeight.TabIndex = 6;
            cmbItemHeight.Text = "";
            cmbItemHeight.Style = System.WinForms.ComboBoxStyle.DropDownList;
            cmbItemHeight.Items.All = (object[])new object[] {"12", "14", "16", "18", "24", "26"};
            cmbItemHeight.AddOnSelectedIndexChanged(new EventHandler(this.cmbItemHeight_SelectedIndexChanged));

            cmbDrawMode.Location = new System.Drawing.Point(128, 120);
            cmbDrawMode.Size = new System.Drawing.Size(104, 21);
            cmbDrawMode.TabIndex = 5;
            cmbDrawMode.Text = "";
            cmbDrawMode.Style = System.WinForms.ComboBoxStyle.DropDownList;
            cmbDrawMode.AddOnSelectedIndexChanged(new EventHandler(this.cmbDrawMode_SelectedIndexChanged));

            cmbStyle.Location = new System.Drawing.Point(128, 96);
            cmbStyle.Size = new System.Drawing.Size(104, 21);
            cmbStyle.TabIndex = 4;
            cmbStyle.Text = "";
            cmbStyle.Style = System.WinForms.ComboBoxStyle.DropDownList;
            cmbStyle.AddOnSelectedIndexChanged(new EventHandler(this.cmbStyle_SelectedIndexChanged));

            comboEnd.Location = new System.Drawing.Point(24, 120);
            comboEnd.Size = new System.Drawing.Size(208, 21);
            comboEnd.TabIndex = 1;
            comboEnd.Text = "comboBegin1";
            comboEnd.Sorted = true;
            comboEnd.AddOnKeyPress(new KeyPressEventHandler(this.combo_KeyPress));
            comboEnd.AddOnDrawItem(new DrawItemEventHandler(this.combo_DrawItem));
            comboEnd.AddOnMeasureItem(new MeasureItemEventHandler(this.combo_MeasureItem));
            comboEnd.AddOnSelectedIndexChanged(new EventHandler(this.comboEnd_SelectedIndexChanged));

            panel1.Location = new System.Drawing.Point(16, 224);
            panel1.Size = new System.Drawing.Size(216, 24);
            panel1.TabIndex = 3;
            panel1.Text = "panel1";
            panel1.BorderStyle = System.WinForms.BorderStyle.Fixed3D;
            panel1.AddOnPaint(new PaintEventHandler(this.panel1_Paint));

            toolTip1.Active = true;
            toolTip1.SetToolTip(comboBegin, "Choose color for left end of gradient");
            toolTip1.SetToolTip(chkSorted, "Sets whether the items in the ComboBoxes\nshould be sorted alphabetically");
            toolTip1.SetToolTip(chkIntegralHeight, "Sets a boolean value indicating\nwhether the combo box should resize\nto avoid showing partial items");
            toolTip1.SetToolTip(cmbMaxDropDownItems, "The number of items to display on dropdown");
            toolTip1.SetToolTip(cmbItemHeight, "The height, in pixels, of an item in the combo box");
            toolTip1.SetToolTip(comboEnd, "Choose the color for the right end of gradient");
            /* @designTimeOnly toolTip1.setLocation(new System.Drawing.Point(136, 232)); */

            label6.Location = new System.Drawing.Point(24, 16);                     
            label6.Size = new System.Drawing.Size(96, 16);
            label6.TabIndex = 5;
            label6.TabStop = false;
            label6.Text = "Left:";

            label7.Location = new System.Drawing.Point(24, 104);
            label7.Size = new System.Drawing.Size(96, 16);
            label7.TabIndex = 3;
            label7.TabStop = false;
            label7.Text = "Right:";

            label5.Location = new System.Drawing.Point(16, 208);
            label5.Size = new System.Drawing.Size(64, 16);
            label5.TabIndex = 12;
            label5.TabStop = false;
            label5.Text = "Left";

            label8.Location = new System.Drawing.Point(136, 208);
            label8.Size = new System.Drawing.Size(64, 0);
            label8.TabIndex = 13;
            label8.TabStop = false;
            label8.Text = "label8";

            label9.Location = new System.Drawing.Point(200, 208);
            label9.Size = new System.Drawing.Size(32, 16);
            label9.TabIndex = 14;
            label9.TabStop = false;
            label9.Text = "Right";

            groupBox1.Controls.Add(panel1);
            groupBox1.Controls.Add(label9);
            groupBox1.Controls.Add(label8);
            groupBox1.Controls.Add(label5);
            groupBox1.Controls.Add(cmbStyle);
            groupBox1.Controls.Add(cmbDrawMode);
            groupBox1.Controls.Add(cmbItemHeight);
            groupBox1.Controls.Add(cmbMaxDropDownItems);
            groupBox1.Controls.Add(label4);
            groupBox1.Controls.Add(label3);
            groupBox1.Controls.Add(label2);
            groupBox1.Controls.Add(label1);
            groupBox1.Controls.Add(chkIntegralHeight);
            groupBox1.Controls.Add(chkSorted);
            groupBox1.Controls.Add(chkEnabled);
            this.Controls.Add(label7);
            this.Controls.Add(label6);
            this.Controls.Add(comboEnd);
            this.Controls.Add(comboBegin);
            this.Controls.Add(groupBox1);
	}

        // The main entry point for the application.
        public static void Main(string[] args) {
            Application.Run(new ComboBoxCtl());
        }

    }

}


