//------------------------------------------------------------------------------
/// <copyright from='1997' to='2001' company='Microsoft Corporation'>           
///    Copyright (c) Microsoft Corporation. All Rights Reserved.                
///       
///    This source code is intended only as a supplement to Microsoft
///    Development Tools and/or on-line documentation.  See these other
///    materials for detailed information regarding Microsoft code samples.
///
/// </copyright>                                                                
//------------------------------------------------------------------------------
namespace DateTimePickerCtl {
    using System;
    using System.ComponentModel;
    using System.Drawing;
    using System.WinForms;

    // <doc>
    // <desc>
    //     This sample control demonstrates various properties and
    //     methods for the DateTimePicker control.  Users should
    //     play with the various controls and then look at the code
    //     behind the behaviors that are most interesting.
    // </desc>
    // </doc>
    //
    public class DateTimePickerCtl : System.WinForms.Form {

        private System.ComponentModel.Container components;
        private System.WinForms.GroupBox groupBox1;
        private System.WinForms.Label label1;
        private System.WinForms.Label label2;
        private System.WinForms.Label label4;
        private System.WinForms.DateTimePicker dateTimePicker;
        private System.WinForms.DateTimePicker dtpMinDate;
        private System.WinForms.DateTimePicker dtpMaxDate;
        private System.WinForms.CheckBox chkShowUpDown;
        private System.WinForms.ComboBox cmbFormat;
        private System.WinForms.Button btnChangeFont;
        private System.WinForms.Button btnChangeColor;
        private System.WinForms.FontDialog fontDialog;
        private System.WinForms.ToolTip toolTip1;

        // <doc>
        // <desc>
        //     Public Constructor
        // </desc>
        // </doc>
        //
        public DateTimePickerCtl() : base() {
             	
            // This call is required for support of the Win Forms Form Designer.
            InitializeComponent();

            // Make sure that we are starting in Long date format
            dateTimePicker.Format = DateTimePickerFormats.Long;
            cmbFormat.SelectedIndex = 0;

            // Initialize the control values
            DateTime now = DateTime.Now;
            dateTimePicker.Value = now;
            dtpMaxDate.Value = now.AddDays(30);
            dtpMinDate.Value = now.AddDays(-30);
            dateTimePicker.MaxDate = dtpMaxDate.Value;
            dateTimePicker.MinDate = dtpMinDate.Value;
        }


        // <doc>
        // <desc>
        //     DateTimePickerCtl overrides dispose so it can clean up the
        //     component list.
        // </desc>
        // </doc>
        //
        public override void Dispose() {
            base.Dispose();
            components.Dispose();
        }

        // <doc>
        // <desc>
        //     Return the DateTimePicker control - used by the 
        //     ChangeColorDlg
        // </desc>
        // </doc>
        //
        internal DateTimePicker DTPicker {
            get {
                return dateTimePicker;
            }
        }

        private void btnChangeFont_Click(object sender, EventArgs e) {
            fontDialog.ShowDialog();
            Font newFont = fontDialog.Font;
            dateTimePicker.Font = newFont;
        }

        private void btnChangeColor_Click(object sender, EventArgs e) {
            ChangeColorDlg dlg = new ChangeColorDlg(this);
            dlg.ShowDialog();
        }

        private void dtpMinDate_ValueChanged(object sender, EventArgs e) {
            dateTimePicker.MinDate = dtpMinDate.Value;
        }

        private void dtpMaxDate_ValueChanged(object sender, EventArgs e) {
            dateTimePicker.MaxDate = dtpMaxDate.Value;
        }
                               
        private void cmbFormat_SelectedIndexChanged(object sender, EventArgs e) {
            if (cmbFormat.SelectedIndex < 0)
                return;

            char firstChar = cmbFormat.SelectedItem.ToString()[0];
            DateTimePickerFormats format;
            switch (firstChar) {
                case 'S':
                    format = DateTimePickerFormats.Short;
                    break;
                case 'T':
                    format = DateTimePickerFormats.Time;
                    break;
                case 'C':
                    format = DateTimePickerFormats.Custom;
                    break;
                default:
                    format = DateTimePickerFormats.Long;
                    break;
            }
            dateTimePicker.Format = format;
        }

        private void chkShowUpDown_Click(object sender, EventArgs e) {
            bool showUpDown = chkShowUpDown.Checked;
            this.dateTimePicker.ShowUpDown = showUpDown;

            btnChangeColor.Enabled = !showUpDown;
            btnChangeFont.Enabled = !showUpDown;
        }

        // NOTE: The following code is required by the Win Forms Form Designer
        // It can be modified using the Win Forms Form Designer.  
        // Do not modify it using the code editor.
        private void InitializeComponent() {
		this.components = new System.ComponentModel.Container();
		this.label4 = new System.WinForms.Label();
		this.dtpMinDate = new System.WinForms.DateTimePicker();
		this.cmbFormat = new System.WinForms.ComboBox();
		this.groupBox1 = new System.WinForms.GroupBox();
		this.label2 = new System.WinForms.Label();
		this.label1 = new System.WinForms.Label();
		this.toolTip1 = new System.WinForms.ToolTip(components);
		this.btnChangeFont = new System.WinForms.Button();
		this.chkShowUpDown = new System.WinForms.CheckBox();
		this.fontDialog = new System.WinForms.FontDialog();
		this.btnChangeColor = new System.WinForms.Button();
		this.dtpMaxDate = new System.WinForms.DateTimePicker();
		this.dateTimePicker = new System.WinForms.DateTimePicker();
		
		label4.TabIndex = 0;
		label4.Size = new System.Drawing.Size(64, 16);
		label4.TabStop = false;
		label4.Location = new System.Drawing.Point(16, 104);
		label4.Text = "Format:";
		
		dtpMinDate.Location = new System.Drawing.Point(128, 48);
		dtpMinDate.TabIndex = 6;
		dtpMinDate.ValueSet = true;
		dtpMinDate.Format = System.WinForms.DateTimePickerFormats.Short;
		dtpMinDate.Size = new System.Drawing.Size(104, 21);
		toolTip1.SetToolTip(dtpMinDate, "The value indicating the first date that\r\nthe control allows the user to select");
		dtpMinDate.AddOnValueChanged(new EventHandler(dtpMinDate_ValueChanged));
		
		cmbFormat.ForeColor = (System.Drawing.Color)System.Drawing.Color.FromKnownColor(System.Drawing.KnownColor.WindowText);
		cmbFormat.Location = new System.Drawing.Point(128, 96);
		cmbFormat.Style = System.WinForms.ComboBoxStyle.DropDownList;
		cmbFormat.TabIndex = 7;
		cmbFormat.Text = "";
		cmbFormat.Size = new System.Drawing.Size(104, 21);
		toolTip1.SetToolTip(cmbFormat, "A value indicating the whether the control displays date and time\r\ninformation in long date Format(for example, \"Wednesday, April 7, 1999\"),\r\nshort date Format(for example, \"4/7/99\"), time Format(for example,\r\n\"5:31:34 PM\"), or custom format.");
		cmbFormat.AddOnSelectedIndexChanged(new EventHandler(cmbFormat_SelectedIndexChanged));
		cmbFormat.Items.All = (object[])new object[] {"Long", "Short", "Time", "Custom"};
		
		groupBox1.TabIndex = 0;
		groupBox1.Size = new System.Drawing.Size(248, 264);
		groupBox1.TabStop = false;
		groupBox1.Location = new System.Drawing.Point(248, 16);
		groupBox1.Text = "DateTimePicker";
		
		this.TabIndex = 0;
		this.Size = new System.Drawing.Size(512, 320);
		this.Text = "DateTimePicker";
		
		label2.TabIndex = 1;
		label2.Size = new System.Drawing.Size(96, 16);
		label2.TabStop = false;
		label2.Location = new System.Drawing.Point(16, 80);
		label2.Text = "MaxDate:";
		
		label1.TabIndex = 3;
		label1.Size = new System.Drawing.Size(80, 16);
		label1.TabStop = false;
		label1.Location = new System.Drawing.Point(16, 56);
		label1.Text = "MinDate:";
		
		toolTip1.Active = true;
		//@design toolTip1.SetLocation(new System.Drawing.Point(20, 40));
		
		btnChangeFont.Location = new System.Drawing.Point(16, 168);
		btnChangeFont.TabIndex = 5;
		btnChangeFont.Text = "Change &Font";
		btnChangeFont.Size = new System.Drawing.Size(75, 23);
		btnChangeFont.AddOnClick(new EventHandler(btnChangeFont_Click));
		
		chkShowUpDown.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
		chkShowUpDown.Location = new System.Drawing.Point(16, 24);
		chkShowUpDown.TabIndex = 8;
		chkShowUpDown.Text = "ShowUpDown";
		chkShowUpDown.Size = new System.Drawing.Size(100, 23);
		chkShowUpDown.AddOnClick(new EventHandler(chkShowUpDown_Click));
		
		//@design fontDialog.SetLocation(new System.Drawing.Point(20, 10));
		
		btnChangeColor.Location = new System.Drawing.Point(96, 168);
		btnChangeColor.TabIndex = 2;
		btnChangeColor.Text = "Change &Color";
		btnChangeColor.Size = new System.Drawing.Size(75, 23);
		btnChangeColor.AddOnClick(new EventHandler(btnChangeColor_Click));
		
		dtpMaxDate.Location = new System.Drawing.Point(128, 72);
		dtpMaxDate.TabIndex = 4;
		dtpMaxDate.ValueSet = true;
		dtpMaxDate.Format = System.WinForms.DateTimePickerFormats.Short;
		dtpMaxDate.Size = new System.Drawing.Size(104, 21);
		toolTip1.SetToolTip(dtpMaxDate, "The value indicating the last date that \r\nthe control allows the user to select");
		dtpMaxDate.AddOnValueChanged(new EventHandler(dtpMaxDate_ValueChanged));
		
		dateTimePicker.Location = new System.Drawing.Point(24, 24);
		dateTimePicker.TabIndex = 1;
		dateTimePicker.ValueSet = true;
		dateTimePicker.Format = System.WinForms.DateTimePickerFormats.Long;
		dateTimePicker.Size = new System.Drawing.Size(200, 21);
		dateTimePicker.CustomFormat = "\'The date is: \'yy MM d - HH\':\'mm\':\'s ddd";
		
		groupBox1.Controls.Add(chkShowUpDown);
		groupBox1.Controls.Add(btnChangeFont);
		groupBox1.Controls.Add(btnChangeColor);
		groupBox1.Controls.Add(dtpMaxDate);
		groupBox1.Controls.Add(dtpMinDate);
		groupBox1.Controls.Add(label4);
		groupBox1.Controls.Add(label2);
		groupBox1.Controls.Add(label1);
		groupBox1.Controls.Add(cmbFormat);
		this.Controls.Add(dateTimePicker);
		this.Controls.Add(groupBox1);
		
	}

        // The main entry point for the application.
        public static void Main(string[] args) {
            Application.Run(new DateTimePickerCtl());
        }


    }

}




