//------------------------------------------------------------------------------
/// <copyright from='1997' to='2001' company='Microsoft Corporation'>           
///    Copyright (c) Microsoft Corporation. All Rights Reserved.                
///       
///    This source code is intended only as a supplement to Microsoft
///    Development Tools and/or on-line documentation.  See these other
///    materials for detailed information regarding Microsoft code samples.
///
/// </copyright>                                                                
/// 
///  Typed DataSet for Customers generated using XSD tool
///  TDGUtil.exe in the QuickStart Utils directory used to generate the XSD
/// 
//------------------------------------------------------------------------------
namespace Microsoft.Samples.WinForms.Cs.WebServiceBinding.Data {
    using System;
    using System.Data;
    using System.Core;
    
    public class CustomersDataSet : DataSet {
        private int tableCount;
        private int relationCount;
        private Customers tableCustomers;
        private Orders tableOrders;
        private DataRelation relationCustomersOrders;
        
        public CustomersDataSet() {
            this.InitClass();
        }
        
        public Customers Customers {
            virtual get {
                return this.tableCustomers;
            }
        }
        public Orders Orders {
            virtual get {
                return this.tableOrders;
            }
        }
        
        private void InitClass() {
            this.DataSetName = "CustomersDataSet";
            this.tableCount = 2;
            this.relationCount = 1;
            this.tableCustomers = new Customers("Customers");
            this.Tables.Add(this.tableCustomers);
            this.tableOrders = new Orders("Orders");
            this.Tables.Add(this.tableOrders);
            this.relationCustomersOrders = new DataRelation("CustomersOrders", DataTable.CreateColumnArray(this.tableCustomers.CustomerIDColumn), DataTable.CreateColumnArray(this.tableOrders.CustomerIDColumn));
            this.Relations.Add(this.relationCustomersOrders);
        }
        protected override bool HasSchemaChanged() {
            return ((((this.tableCount) != (this.Tables.Count))) || (((this.relationCount) != (this.Relations.Count))));
        }
        protected override void OnRemoveRelation(DataRelation relation) {
            if (((relation) == (this.relationCustomersOrders))) {
                throw new ArgumentException("Can't remove relation since it it built in to this dataSet");
            }
        }
        public override bool ShouldPersistTables() {
            return ((this.tableCount) != (this.Tables.Count));
        }
        public override bool ShouldPersistRelations() {
            return ((this.relationCount) != (this.Relations.Count));
        }
        public override void ResetTables() {
            for (int i = 0; ((i) < (this.Tables.Count)); i = ((i) + (1))) {
                if (((((this.Tables[i]) == (this.tableOrders))) || (((this.Tables[i]) == (this.tableCustomers))))) {
                }
                else {
                    this.Tables.Remove(this.Tables[i]);
                }
            }
        }
        public override void ResetRelations() {
            for (int i = 0; ((i) < (this.Relations.Count)); i = ((i) + (1))) {
                if (((this.Relations[i]) == (this.relationCustomersOrders))) {
                }
                else {
                    this.Relations.Remove(this.Relations[i]);
                }
            }
        }
        protected override void OnRemoveTable(DataTable table) {
            if (((((table) == (this.tableOrders))) || (((table) == (this.tableCustomers))))) {
                throw new ArgumentException("Can't remove relation since it it built in to this dataSet");
            }
        }
        
    }
    public class Customers : DataTable, System.Collections.ICollection {
        private int columnCount;
        private int constraintCount;
        private Customers_CustomerID columnCustomerID;
        private Customers_CompanyName columnCompanyName;
        private Customers_ContactName columnContactName;
        private Customers_ContactTitle columnContactTitle;
        private Customers_Address columnAddress;
        private Customers_City columnCity;
        private Customers_Region columnRegion;
        private Customers_PostalCode columnPostalCode;
        private Customers_Country columnCountry;
        private Customers_Phone columnPhone;
        private Customers_Fax columnFax;
        private Constraint constraintConstraint1=null;
        private DataColumn[] indexByCustomerID;
        private CustomersRowChangeEventHandler CustomersRowChanged;
        private CustomersRowChangeEventHandler CustomersRowChanging;
        private DataColumnChangeEventHandler CustomerIDColumnChanging;
        private DataColumnChangeEventHandler CompanyNameColumnChanging;
        private DataColumnChangeEventHandler ContactNameColumnChanging;
        private DataColumnChangeEventHandler ContactTitleColumnChanging;
        private DataColumnChangeEventHandler AddressColumnChanging;
        private DataColumnChangeEventHandler CityColumnChanging;
        private DataColumnChangeEventHandler RegionColumnChanging;
        private DataColumnChangeEventHandler PostalCodeColumnChanging;
        private DataColumnChangeEventHandler CountryColumnChanging;
        private DataColumnChangeEventHandler PhoneColumnChanging;
        private DataColumnChangeEventHandler FaxColumnChanging;
        
        public Customers(string name) : 
                base(name) {
            this.InitClass();
        }
        public Customers() : 
                base("Customers") {
            this.InitClass();
        }
        
        public int Count {
            virtual get {
                return this.Rows.Count;
            }
        }
        public bool IsReadOnly {
            virtual get {
                return false;
            }
        }
        public bool IsSynchronized {
            virtual get {
                return false;
            }
        }
        public object SyncRoot {
            virtual get {
                return this;
            }
        }
        public Customers_CustomerID CustomerIDColumn {
            virtual get {
                return this.columnCustomerID;
            }
        }
        public Customers_CompanyName CompanyNameColumn {
            virtual get {
                return this.columnCompanyName;
            }
        }
        public Customers_ContactName ContactNameColumn {
            virtual get {
                return this.columnContactName;
            }
        }
        public Customers_ContactTitle ContactTitleColumn {
            virtual get {
                return this.columnContactTitle;
            }
        }
        public Customers_Address AddressColumn {
            virtual get {
                return this.columnAddress;
            }
        }
        public Customers_City CityColumn {
            virtual get {
                return this.columnCity;
            }
        }
        public Customers_Region RegionColumn {
            virtual get {
                return this.columnRegion;
            }
        }
        public Customers_PostalCode PostalCodeColumn {
            virtual get {
                return this.columnPostalCode;
            }
        }
        public Customers_Country CountryColumn {
            virtual get {
                return this.columnCountry;
            }
        }
        public Customers_Phone PhoneColumn {
            virtual get {
                return this.columnPhone;
            }
        }
        public Customers_Fax FaxColumn {
            virtual get {
                return this.columnFax;
            }
        }
        public CustomersRow this[int index] {
            virtual get {
                return (CustomersRow)(this.Rows[index]);
            }
        }
        
        public virtual void AddCustomersRow(CustomersRow rowCustomersRow) {
            this.Rows.Add(rowCustomersRow);
        }
        public virtual CustomersRow AddCustomersRow(string columnCustomerID, string columnCompanyName, string columnContactName, string columnContactTitle, string columnAddress, string columnCity, string columnRegion, string columnPostalCode, string columnCountry, string columnPhone, string columnFax) {
            CustomersRow rowCustomersRow;
            rowCustomersRow = (CustomersRow)(this.NewRow());
            rowCustomersRow.ItemArray = new Object[] {columnCustomerID,
                    columnCompanyName,
                    columnContactName,
                    columnContactTitle,
                    columnAddress,
                    columnCity,
                    columnRegion,
                    columnPostalCode,
                    columnCountry,
                    columnPhone,
                    columnFax};
            this.Rows.Add(rowCustomersRow);
            return rowCustomersRow;
        }
        public virtual void AddOnCustomersRowChanged(CustomersRowChangeEventHandler handler) {
            this.CustomersRowChanged = (CustomersRowChangeEventHandler)(System.Delegate.Combine(this.CustomersRowChanged, handler));
        }
        public virtual void AddOnCustomersRowChanging(CustomersRowChangeEventHandler handler) {
            this.CustomersRowChanging = (CustomersRowChangeEventHandler)(System.Delegate.Combine(this.CustomersRowChanging, handler));
        }
        public virtual void RemoveOnCustomersRowChanged(CustomersRowChangeEventHandler handler) {
            this.CustomersRowChanged = (CustomersRowChangeEventHandler)(System.Delegate.Remove(this.CustomersRowChanged, handler));
        }
        public virtual void RemoveOnCustomersRowChanging(CustomersRowChangeEventHandler handler) {
            this.CustomersRowChanging = (CustomersRowChangeEventHandler)(System.Delegate.Remove(this.CustomersRowChanging, handler));
        }
        public virtual void AddOnCustomerIDColumnChanging(DataColumnChangeEventHandler handler) {
            this.CustomerIDColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Combine(this.CustomerIDColumnChanging, handler));
        }
        public virtual void RemoveOnCustomerIDColumnChanging(DataColumnChangeEventHandler handler) {
            this.CustomerIDColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Remove(this.CustomerIDColumnChanging, handler));
        }
        public virtual void AddOnCompanyNameColumnChanging(DataColumnChangeEventHandler handler) {
            this.CompanyNameColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Combine(this.CompanyNameColumnChanging, handler));
        }
        public virtual void RemoveOnCompanyNameColumnChanging(DataColumnChangeEventHandler handler) {
            this.CompanyNameColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Remove(this.CompanyNameColumnChanging, handler));
        }
        public virtual void AddOnContactNameColumnChanging(DataColumnChangeEventHandler handler) {
            this.ContactNameColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Combine(this.ContactNameColumnChanging, handler));
        }
        public virtual void RemoveOnContactNameColumnChanging(DataColumnChangeEventHandler handler) {
            this.ContactNameColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Remove(this.ContactNameColumnChanging, handler));
        }
        public virtual void AddOnContactTitleColumnChanging(DataColumnChangeEventHandler handler) {
            this.ContactTitleColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Combine(this.ContactTitleColumnChanging, handler));
        }
        public virtual void RemoveOnContactTitleColumnChanging(DataColumnChangeEventHandler handler) {
            this.ContactTitleColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Remove(this.ContactTitleColumnChanging, handler));
        }
        public virtual void AddOnAddressColumnChanging(DataColumnChangeEventHandler handler) {
            this.AddressColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Combine(this.AddressColumnChanging, handler));
        }
        public virtual void RemoveOnAddressColumnChanging(DataColumnChangeEventHandler handler) {
            this.AddressColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Remove(this.AddressColumnChanging, handler));
        }
        public virtual void AddOnCityColumnChanging(DataColumnChangeEventHandler handler) {
            this.CityColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Combine(this.CityColumnChanging, handler));
        }
        public virtual void RemoveOnCityColumnChanging(DataColumnChangeEventHandler handler) {
            this.CityColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Remove(this.CityColumnChanging, handler));
        }
        public virtual void AddOnRegionColumnChanging(DataColumnChangeEventHandler handler) {
            this.RegionColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Combine(this.RegionColumnChanging, handler));
        }
        public virtual void RemoveOnRegionColumnChanging(DataColumnChangeEventHandler handler) {
            this.RegionColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Remove(this.RegionColumnChanging, handler));
        }
        public virtual void AddOnPostalCodeColumnChanging(DataColumnChangeEventHandler handler) {
            this.PostalCodeColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Combine(this.PostalCodeColumnChanging, handler));
        }
        public virtual void RemoveOnPostalCodeColumnChanging(DataColumnChangeEventHandler handler) {
            this.PostalCodeColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Remove(this.PostalCodeColumnChanging, handler));
        }
        public virtual void AddOnCountryColumnChanging(DataColumnChangeEventHandler handler) {
            this.CountryColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Combine(this.CountryColumnChanging, handler));
        }
        public virtual void RemoveOnCountryColumnChanging(DataColumnChangeEventHandler handler) {
            this.CountryColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Remove(this.CountryColumnChanging, handler));
        }
        public virtual void AddOnPhoneColumnChanging(DataColumnChangeEventHandler handler) {
            this.PhoneColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Combine(this.PhoneColumnChanging, handler));
        }
        public virtual void RemoveOnPhoneColumnChanging(DataColumnChangeEventHandler handler) {
            this.PhoneColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Remove(this.PhoneColumnChanging, handler));
        }
        public virtual void AddOnFaxColumnChanging(DataColumnChangeEventHandler handler) {
            this.FaxColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Combine(this.FaxColumnChanging, handler));
        }
        public virtual void RemoveOnFaxColumnChanging(DataColumnChangeEventHandler handler) {
            this.FaxColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Remove(this.FaxColumnChanging, handler));
        }
        public virtual void CopyTo(Array array, int offset) {
            for (int i = 0; ((i) < (this.Rows.Count)); i = ((i) + (1))) {
                array.SetValue(this.Rows[i], ((i) + (offset)));
            }
        }
        public virtual CustomersRow FindByCustomerID(string columnCustomerID) {
            return (CustomersRow)(this.Rows.Find(new Object[] {columnCustomerID}));
        }
        public virtual System.Collections.IEnumerator GetEnumerator() {
            return this.Rows.All.GetEnumerator();
        }
        protected override bool HasSchemaChanged() {
            return ((this.columnCount) == (this.Columns.Count));
        }
        private void InitClass() {
            this.columnCount = 11;
            this.constraintCount = 1;
            this.columnCustomerID = new Customers_CustomerID();
            this.Columns.Add(this.columnCustomerID);
            this.columnCompanyName = new Customers_CompanyName();
            this.Columns.Add(this.columnCompanyName);
            this.columnContactName = new Customers_ContactName();
            this.Columns.Add(this.columnContactName);
            this.columnContactTitle = new Customers_ContactTitle();
            this.Columns.Add(this.columnContactTitle);
            this.columnAddress = new Customers_Address();
            this.Columns.Add(this.columnAddress);
            this.columnCity = new Customers_City();
            this.Columns.Add(this.columnCity);
            this.columnRegion = new Customers_Region();
            this.Columns.Add(this.columnRegion);
            this.columnPostalCode = new Customers_PostalCode();
            this.Columns.Add(this.columnPostalCode);
            this.columnCountry = new Customers_Country();
            this.Columns.Add(this.columnCountry);
            this.columnPhone = new Customers_Phone();
            this.Columns.Add(this.columnPhone);
            this.columnFax = new Customers_Fax();
            this.Columns.Add(this.columnFax);
            this.PrimaryKey = System.Data.DataTable.CreateColumnArray(this.columnCustomerID);
            this.indexByCustomerID = System.Data.DataTable.CreateColumnArray(this.columnCustomerID);
        }
        public virtual CustomersRow NewCustomersRow() {
            return (CustomersRow)(this.NewRow());
        }
        protected override DataRow NewRowFromBuilder(DataRowBuilder builder) {
            /*We need to ensure that all Rows in the tabled are typed rows.*/
            /*Table calls newRow whenever it needs to create a row.*/
            /*So the following conditions are covered by Row newRow(Record record)*/
            /** Cursor calls table.addRecord(record) */
            /** table.addRow(object[] values) calls newRow(record)    */
            return new CustomersRow(builder);
        }
        protected override void OnRemoveColumn(DataColumn column) {
            if (((((((((((((((((((((((column) == (this.columnCustomerID))) || (((column) == (this.columnCompanyName))))) || (((column) == (this.columnContactName))))) || (((column) == (this.columnContactTitle))))) || (((column) == (this.columnAddress))))) || (((column) == (this.columnCity))))) || (((column) == (this.columnRegion))))) || (((column) == (this.columnPostalCode))))) || (((column) == (this.columnCountry))))) || (((column) == (this.columnPhone))))) || (((column) == (this.columnFax))))) {
                throw new ArgumentException("Can't remove column since it it built in to this dataSet");
            }
        }
        protected override void OnRowChanged(DataRowChangeEventArgs e) {
            base.OnRowChanged(e);
            if (((this.CustomersRowChanged) == (null))) {
                this.CustomersRowChanged(this, new CustomersRowChangeEvent((CustomersRow)(e.Row), e.Action));
            }
        }
        protected override void OnRowChanging(DataRowChangeEventArgs e) {
            if (((this.CustomersRowChanging) != (null))) {
                this.CustomersRowChanging(this, new CustomersRowChangeEvent((CustomersRow)(e.Row), e.Action));
            }
        }
        protected virtual void OnCustomerIDColumnChanging(DataColumnChangeEventArgs e) {
            if (((this.CustomerIDColumnChanging) != (null))) {
                this.CustomerIDColumnChanging(this, e);
            }
        }
        protected virtual void OnCompanyNameColumnChanging(DataColumnChangeEventArgs e) {
            if (((this.CompanyNameColumnChanging) != (null))) {
                this.CompanyNameColumnChanging(this, e);
            }
        }
        protected virtual void OnContactNameColumnChanging(DataColumnChangeEventArgs e) {
            if (((this.ContactNameColumnChanging) != (null))) {
                this.ContactNameColumnChanging(this, e);
            }
        }
        protected virtual void OnContactTitleColumnChanging(DataColumnChangeEventArgs e) {
            if (((this.ContactTitleColumnChanging) != (null))) {
                this.ContactTitleColumnChanging(this, e);
            }
        }
        protected virtual void OnAddressColumnChanging(DataColumnChangeEventArgs e) {
            if (((this.AddressColumnChanging) != (null))) {
                this.AddressColumnChanging(this, e);
            }
        }
        protected virtual void OnCityColumnChanging(DataColumnChangeEventArgs e) {
            if (((this.CityColumnChanging) != (null))) {
                this.CityColumnChanging(this, e);
            }
        }
        protected virtual void OnRegionColumnChanging(DataColumnChangeEventArgs e) {
            if (((this.RegionColumnChanging) != (null))) {
                this.RegionColumnChanging(this, e);
            }
        }
        protected virtual void OnPostalCodeColumnChanging(DataColumnChangeEventArgs e) {
            if (((this.PostalCodeColumnChanging) != (null))) {
                this.PostalCodeColumnChanging(this, e);
            }
        }
        protected virtual void OnCountryColumnChanging(DataColumnChangeEventArgs e) {
            if (((this.CountryColumnChanging) != (null))) {
                this.CountryColumnChanging(this, e);
            }
        }
        protected virtual void OnPhoneColumnChanging(DataColumnChangeEventArgs e) {
            if (((this.PhoneColumnChanging) != (null))) {
                this.PhoneColumnChanging(this, e);
            }
        }
        protected virtual void OnFaxColumnChanging(DataColumnChangeEventArgs e) {
            if (((this.FaxColumnChanging) != (null))) {
                this.FaxColumnChanging(this, e);
            }
        }
        protected override void OnColumnChanging(DataColumnChangeEventArgs e) {
            base.OnColumnChanging(e);
            if (((e.Column) == (this.columnCustomerID))) {
                this.OnCustomerIDColumnChanging(e);
            }
            else {
                if (((e.Column) == (this.columnCompanyName))) {
                    this.OnCompanyNameColumnChanging(e);
                }
                else {
                    if (((e.Column) == (this.columnContactName))) {
                        this.OnContactNameColumnChanging(e);
                    }
                    else {
                        if (((e.Column) == (this.columnContactTitle))) {
                            this.OnContactTitleColumnChanging(e);
                        }
                        else {
                            if (((e.Column) == (this.columnAddress))) {
                                this.OnAddressColumnChanging(e);
                            }
                            else {
                                if (((e.Column) == (this.columnCity))) {
                                    this.OnCityColumnChanging(e);
                                }
                                else {
                                    if (((e.Column) == (this.columnRegion))) {
                                        this.OnRegionColumnChanging(e);
                                    }
                                    else {
                                        if (((e.Column) == (this.columnPostalCode))) {
                                            this.OnPostalCodeColumnChanging(e);
                                        }
                                        else {
                                            if (((e.Column) == (this.columnCountry))) {
                                                this.OnCountryColumnChanging(e);
                                            }
                                            else {
                                                if (((e.Column) == (this.columnPhone))) {
                                                    this.OnPhoneColumnChanging(e);
                                                }
                                                else {
                                                    if (((e.Column) == (this.columnFax))) {
                                                        this.OnFaxColumnChanging(e);
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
        public virtual void RemoveCustomersRow(CustomersRow rowCustomersRow) {
            this.Rows.Remove(rowCustomersRow);
        }
        public override bool ShouldPersistPrimaryKey() {
            return false;
        }
        public override void ResetPrimaryKey() {
        }
        public override bool ShouldPersistColumns() {
            return ((this.columnCount) != (this.Columns.Count));
        }
        public override void ResetColumns() {
            for (int i = 0; ((i) < (this.Columns.Count)); i = ((i) + (1))) {
                if (((((this.Columns[i]) == (this.columnFax))) || (((((this.Columns[i]) == (this.columnPhone))) || (((((this.Columns[i]) == (this.columnCountry))) || (((((this.Columns[i]) == (this.columnPostalCode))) || (((((this.Columns[i]) == (this.columnRegion))) || (((((this.Columns[i]) == (this.columnCity))) || (((((this.Columns[i]) == (this.columnAddress))) || (((((this.Columns[i]) == (this.columnContactTitle))) || (((((this.Columns[i]) == (this.columnContactName))) || (((((this.Columns[i]) == (this.columnCompanyName))) || (((this.Columns[i]) == (this.columnCustomerID))))))))))))))))))))))) {
                }
                else {
                    this.Columns.Remove(this.Columns[i]);
                }
            }
        }
        public override bool ShouldPersistConstraints() {
            return ((this.constraintCount) != (this.Constraints.Count));
        }
        public override void ResetConstraints() {
            for (int i = 0; ((i) < (this.Constraints.Count)); i = ((i) + (1))) {
                if (((this.Constraints[i]) == (this.constraintConstraint1))) {
                }
                else {
                    this.Constraints.Remove(this.Constraints[i]);
                }
            }
        }
        
    }
    public class Customers_CustomerID : System.Data.DataColumn {
        public Customers_CustomerID() : 
                base("CustomerID", typeof(string)) {
            this.InitClass();
        }
        
        public virtual void InitClass() {
            this.AllowNull = false;
            this.Unique = true;
        }
        
    }
    public class Customers_CompanyName : System.Data.DataColumn {
        public Customers_CompanyName() : 
                base("CompanyName", typeof(string)) {
            this.InitClass();
        }
        
        public virtual void InitClass() {
            this.AllowNull = false;
        }
        
    }
    public class Customers_ContactName : System.Data.DataColumn {
        public Customers_ContactName() : 
                base("ContactName", typeof(string)) {
            this.InitClass();
        }
        
        public virtual void InitClass() {
        }
        
    }
    public class Customers_ContactTitle : System.Data.DataColumn {
        public Customers_ContactTitle() : 
                base("ContactTitle", typeof(string)) {
            this.InitClass();
        }
        
        public virtual void InitClass() {
        }
        
    }
    public class Customers_Address : System.Data.DataColumn {
        public Customers_Address() : 
                base("Address", typeof(string)) {
            this.InitClass();
        }
        
        public virtual void InitClass() {
        }
        
    }
    public class Customers_City : System.Data.DataColumn {
        public Customers_City() : 
                base("City", typeof(string)) {
            this.InitClass();
        }
        
        public virtual void InitClass() {
        }
        
    }
    public class Customers_Region : System.Data.DataColumn {
        public Customers_Region() : 
                base("Region", typeof(string)) {
            this.InitClass();
        }
        
        public virtual void InitClass() {
        }
        
    }
    public class Customers_PostalCode : System.Data.DataColumn {
        public Customers_PostalCode() : 
                base("PostalCode", typeof(string)) {
            this.InitClass();
        }
        
        public virtual void InitClass() {
        }
        
    }
    public class Customers_Country : System.Data.DataColumn {
        public Customers_Country() : 
                base("Country", typeof(string)) {
            this.InitClass();
        }
        
        public virtual void InitClass() {
        }
        
    }
    public class Customers_Phone : System.Data.DataColumn {
        public Customers_Phone() : 
                base("Phone", typeof(string)) {
            this.InitClass();
        }
        
        public virtual void InitClass() {
        }
        
    }
    public class Customers_Fax : System.Data.DataColumn {
        public Customers_Fax() : 
                base("Fax", typeof(string)) {
            this.InitClass();
        }
        
        public virtual void InitClass() {
        }
        
    }
    public class Orders : DataTable, System.Collections.ICollection {
        private int columnCount;
        private int constraintCount;
        private Orders_OrderID columnOrderID;
        private Orders_CustomerID columnCustomerID;
        private Orders_EmployeeID columnEmployeeID;
        private Orders_OrderDate columnOrderDate;
        private Orders_RequiredDate columnRequiredDate;
        private Orders_ShippedDate columnShippedDate;
        private Orders_ShipVia columnShipVia;
        private Orders_Freight columnFreight;
        private Orders_ShipName columnShipName;
        private Orders_ShipAddress columnShipAddress;
        private Orders_ShipCity columnShipCity;
        private Orders_ShipRegion columnShipRegion;
        private Orders_ShipPostalCode columnShipPostalCode;
        private Orders_ShipCountry columnShipCountry;
        private Constraint constraintConstraint1=null;
        private DataColumn[] indexByOrderID;
        private Constraint constraintCustomersOrders=null;
        private OrdersRowChangeEventHandler OrdersRowChanged;
        private OrdersRowChangeEventHandler OrdersRowChanging;
        private DataColumnChangeEventHandler OrderIDColumnChanging;
        private DataColumnChangeEventHandler CustomerIDColumnChanging;
        private DataColumnChangeEventHandler EmployeeIDColumnChanging;
        private DataColumnChangeEventHandler OrderDateColumnChanging;
        private DataColumnChangeEventHandler RequiredDateColumnChanging;
        private DataColumnChangeEventHandler ShippedDateColumnChanging;
        private DataColumnChangeEventHandler ShipViaColumnChanging;
        private DataColumnChangeEventHandler FreightColumnChanging;
        private DataColumnChangeEventHandler ShipNameColumnChanging;
        private DataColumnChangeEventHandler ShipAddressColumnChanging;
        private DataColumnChangeEventHandler ShipCityColumnChanging;
        private DataColumnChangeEventHandler ShipRegionColumnChanging;
        private DataColumnChangeEventHandler ShipPostalCodeColumnChanging;
        private DataColumnChangeEventHandler ShipCountryColumnChanging;
        
        public Orders(string name) : 
                base(name) {
            this.InitClass();
        }
        public Orders() : 
                base("Orders") {
            this.InitClass();
        }
        
        public int Count {
            virtual get {
                return this.Rows.Count;
            }
        }
        public bool IsReadOnly {
            virtual get {
                return false;
            }
        }
        public bool IsSynchronized {
            virtual get {
                return false;
            }
        }
        public object SyncRoot {
            virtual get {
                return this;
            }
        }
        public Orders_OrderID OrderIDColumn {
            virtual get {
                return this.columnOrderID;
            }
        }
        public Orders_CustomerID CustomerIDColumn {
            virtual get {
                return this.columnCustomerID;
            }
        }
        public Orders_EmployeeID EmployeeIDColumn {
            virtual get {
                return this.columnEmployeeID;
            }
        }
        public Orders_OrderDate OrderDateColumn {
            virtual get {
                return this.columnOrderDate;
            }
        }
        public Orders_RequiredDate RequiredDateColumn {
            virtual get {
                return this.columnRequiredDate;
            }
        }
        public Orders_ShippedDate ShippedDateColumn {
            virtual get {
                return this.columnShippedDate;
            }
        }
        public Orders_ShipVia ShipViaColumn {
            virtual get {
                return this.columnShipVia;
            }
        }
        public Orders_Freight FreightColumn {
            virtual get {
                return this.columnFreight;
            }
        }
        public Orders_ShipName ShipNameColumn {
            virtual get {
                return this.columnShipName;
            }
        }
        public Orders_ShipAddress ShipAddressColumn {
            virtual get {
                return this.columnShipAddress;
            }
        }
        public Orders_ShipCity ShipCityColumn {
            virtual get {
                return this.columnShipCity;
            }
        }
        public Orders_ShipRegion ShipRegionColumn {
            virtual get {
                return this.columnShipRegion;
            }
        }
        public Orders_ShipPostalCode ShipPostalCodeColumn {
            virtual get {
                return this.columnShipPostalCode;
            }
        }
        public Orders_ShipCountry ShipCountryColumn {
            virtual get {
                return this.columnShipCountry;
            }
        }
        public OrdersRow this[int index] {
            virtual get {
                return (OrdersRow)(this.Rows[index]);
            }
        }
        
        public virtual void AddOrdersRow(OrdersRow rowOrdersRow) {
            this.Rows.Add(rowOrdersRow);
        }
        public virtual OrdersRow AddOrdersRow(CustomersRow parentCustomersRowByCustomersOrders, int columnEmployeeID, System.DateTime columnOrderDate, System.DateTime columnRequiredDate, System.DateTime columnShippedDate, int columnShipVia, System.Currency columnFreight, string columnShipName, string columnShipAddress, string columnShipCity, string columnShipRegion, string columnShipPostalCode, string columnShipCountry) {
            OrdersRow rowOrdersRow;
            rowOrdersRow = (OrdersRow)(this.NewRow());
            rowOrdersRow.ItemArray = new Object[] {null,
                    parentCustomersRowByCustomersOrders.CustomerID,
                    columnEmployeeID,
                    columnOrderDate,
                    columnRequiredDate,
                    columnShippedDate,
                    columnShipVia,
                    columnFreight,
                    columnShipName,
                    columnShipAddress,
                    columnShipCity,
                    columnShipRegion,
                    columnShipPostalCode,
                    columnShipCountry};
            this.Rows.Add(rowOrdersRow);
            return rowOrdersRow;
        }
        public virtual void AddOnOrdersRowChanged(OrdersRowChangeEventHandler handler) {
            this.OrdersRowChanged = (OrdersRowChangeEventHandler)(System.Delegate.Combine(this.OrdersRowChanged, handler));
        }
        public virtual void AddOnOrdersRowChanging(OrdersRowChangeEventHandler handler) {
            this.OrdersRowChanging = (OrdersRowChangeEventHandler)(System.Delegate.Combine(this.OrdersRowChanging, handler));
        }
        public virtual void RemoveOnOrdersRowChanged(OrdersRowChangeEventHandler handler) {
            this.OrdersRowChanged = (OrdersRowChangeEventHandler)(System.Delegate.Remove(this.OrdersRowChanged, handler));
        }
        public virtual void RemoveOnOrdersRowChanging(OrdersRowChangeEventHandler handler) {
            this.OrdersRowChanging = (OrdersRowChangeEventHandler)(System.Delegate.Remove(this.OrdersRowChanging, handler));
        }
        public virtual void AddOnOrderIDColumnChanging(DataColumnChangeEventHandler handler) {
            this.OrderIDColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Combine(this.OrderIDColumnChanging, handler));
        }
        public virtual void RemoveOnOrderIDColumnChanging(DataColumnChangeEventHandler handler) {
            this.OrderIDColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Remove(this.OrderIDColumnChanging, handler));
        }
        public virtual void AddOnCustomerIDColumnChanging(DataColumnChangeEventHandler handler) {
            this.CustomerIDColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Combine(this.CustomerIDColumnChanging, handler));
        }
        public virtual void RemoveOnCustomerIDColumnChanging(DataColumnChangeEventHandler handler) {
            this.CustomerIDColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Remove(this.CustomerIDColumnChanging, handler));
        }
        public virtual void AddOnEmployeeIDColumnChanging(DataColumnChangeEventHandler handler) {
            this.EmployeeIDColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Combine(this.EmployeeIDColumnChanging, handler));
        }
        public virtual void RemoveOnEmployeeIDColumnChanging(DataColumnChangeEventHandler handler) {
            this.EmployeeIDColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Remove(this.EmployeeIDColumnChanging, handler));
        }
        public virtual void AddOnOrderDateColumnChanging(DataColumnChangeEventHandler handler) {
            this.OrderDateColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Combine(this.OrderDateColumnChanging, handler));
        }
        public virtual void RemoveOnOrderDateColumnChanging(DataColumnChangeEventHandler handler) {
            this.OrderDateColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Remove(this.OrderDateColumnChanging, handler));
        }
        public virtual void AddOnRequiredDateColumnChanging(DataColumnChangeEventHandler handler) {
            this.RequiredDateColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Combine(this.RequiredDateColumnChanging, handler));
        }
        public virtual void RemoveOnRequiredDateColumnChanging(DataColumnChangeEventHandler handler) {
            this.RequiredDateColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Remove(this.RequiredDateColumnChanging, handler));
        }
        public virtual void AddOnShippedDateColumnChanging(DataColumnChangeEventHandler handler) {
            this.ShippedDateColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Combine(this.ShippedDateColumnChanging, handler));
        }
        public virtual void RemoveOnShippedDateColumnChanging(DataColumnChangeEventHandler handler) {
            this.ShippedDateColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Remove(this.ShippedDateColumnChanging, handler));
        }
        public virtual void AddOnShipViaColumnChanging(DataColumnChangeEventHandler handler) {
            this.ShipViaColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Combine(this.ShipViaColumnChanging, handler));
        }
        public virtual void RemoveOnShipViaColumnChanging(DataColumnChangeEventHandler handler) {
            this.ShipViaColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Remove(this.ShipViaColumnChanging, handler));
        }
        public virtual void AddOnFreightColumnChanging(DataColumnChangeEventHandler handler) {
            this.FreightColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Combine(this.FreightColumnChanging, handler));
        }
        public virtual void RemoveOnFreightColumnChanging(DataColumnChangeEventHandler handler) {
            this.FreightColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Remove(this.FreightColumnChanging, handler));
        }
        public virtual void AddOnShipNameColumnChanging(DataColumnChangeEventHandler handler) {
            this.ShipNameColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Combine(this.ShipNameColumnChanging, handler));
        }
        public virtual void RemoveOnShipNameColumnChanging(DataColumnChangeEventHandler handler) {
            this.ShipNameColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Remove(this.ShipNameColumnChanging, handler));
        }
        public virtual void AddOnShipAddressColumnChanging(DataColumnChangeEventHandler handler) {
            this.ShipAddressColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Combine(this.ShipAddressColumnChanging, handler));
        }
        public virtual void RemoveOnShipAddressColumnChanging(DataColumnChangeEventHandler handler) {
            this.ShipAddressColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Remove(this.ShipAddressColumnChanging, handler));
        }
        public virtual void AddOnShipCityColumnChanging(DataColumnChangeEventHandler handler) {
            this.ShipCityColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Combine(this.ShipCityColumnChanging, handler));
        }
        public virtual void RemoveOnShipCityColumnChanging(DataColumnChangeEventHandler handler) {
            this.ShipCityColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Remove(this.ShipCityColumnChanging, handler));
        }
        public virtual void AddOnShipRegionColumnChanging(DataColumnChangeEventHandler handler) {
            this.ShipRegionColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Combine(this.ShipRegionColumnChanging, handler));
        }
        public virtual void RemoveOnShipRegionColumnChanging(DataColumnChangeEventHandler handler) {
            this.ShipRegionColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Remove(this.ShipRegionColumnChanging, handler));
        }
        public virtual void AddOnShipPostalCodeColumnChanging(DataColumnChangeEventHandler handler) {
            this.ShipPostalCodeColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Combine(this.ShipPostalCodeColumnChanging, handler));
        }
        public virtual void RemoveOnShipPostalCodeColumnChanging(DataColumnChangeEventHandler handler) {
            this.ShipPostalCodeColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Remove(this.ShipPostalCodeColumnChanging, handler));
        }
        public virtual void AddOnShipCountryColumnChanging(DataColumnChangeEventHandler handler) {
            this.ShipCountryColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Combine(this.ShipCountryColumnChanging, handler));
        }
        public virtual void RemoveOnShipCountryColumnChanging(DataColumnChangeEventHandler handler) {
            this.ShipCountryColumnChanging = (DataColumnChangeEventHandler)(System.Delegate.Remove(this.ShipCountryColumnChanging, handler));
        }
        public virtual void CopyTo(Array array, int offset) {
            for (int i = 0; ((i) < (this.Rows.Count)); i = ((i) + (1))) {
                array.SetValue(this.Rows[i], ((i) + (offset)));
            }
        }
        public virtual OrdersRow FindByOrderID(int columnOrderID) {
            return (OrdersRow)(this.Rows.Find(new Object[] {columnOrderID}));
        }
        public virtual System.Collections.IEnumerator GetEnumerator() {
            return this.Rows.All.GetEnumerator();
        }
        protected override bool HasSchemaChanged() {
            return ((this.columnCount) == (this.Columns.Count));
        }
        private void InitClass() {
            this.columnCount = 14;
            this.constraintCount = 2;
            this.columnOrderID = new Orders_OrderID();
            this.Columns.Add(this.columnOrderID);
            this.columnCustomerID = new Orders_CustomerID();
            this.Columns.Add(this.columnCustomerID);
            this.columnEmployeeID = new Orders_EmployeeID();
            this.Columns.Add(this.columnEmployeeID);
            this.columnOrderDate = new Orders_OrderDate();
            this.Columns.Add(this.columnOrderDate);
            this.columnRequiredDate = new Orders_RequiredDate();
            this.Columns.Add(this.columnRequiredDate);
            this.columnShippedDate = new Orders_ShippedDate();
            this.Columns.Add(this.columnShippedDate);
            this.columnShipVia = new Orders_ShipVia();
            this.Columns.Add(this.columnShipVia);
            this.columnFreight = new Orders_Freight();
            this.Columns.Add(this.columnFreight);
            this.columnShipName = new Orders_ShipName();
            this.Columns.Add(this.columnShipName);
            this.columnShipAddress = new Orders_ShipAddress();
            this.Columns.Add(this.columnShipAddress);
            this.columnShipCity = new Orders_ShipCity();
            this.Columns.Add(this.columnShipCity);
            this.columnShipRegion = new Orders_ShipRegion();
            this.Columns.Add(this.columnShipRegion);
            this.columnShipPostalCode = new Orders_ShipPostalCode();
            this.Columns.Add(this.columnShipPostalCode);
            this.columnShipCountry = new Orders_ShipCountry();
            this.Columns.Add(this.columnShipCountry);
            this.PrimaryKey = System.Data.DataTable.CreateColumnArray(this.columnOrderID);
            this.indexByOrderID = System.Data.DataTable.CreateColumnArray(this.columnOrderID);
        }
        public virtual OrdersRow NewOrdersRow() {
            return (OrdersRow)(this.NewRow());
        }
        protected override DataRow NewRowFromBuilder(DataRowBuilder builder) {
            /*We need to ensure that all Rows in the tabled are typed rows.*/
            /*Table calls newRow whenever it needs to create a row.*/
            /*So the following conditions are covered by Row newRow(Record record)*/
            /** Cursor calls table.addRecord(record) */
            /** table.addRow(object[] values) calls newRow(record)    */
            return new OrdersRow(builder);
        }
        protected override void OnRemoveColumn(DataColumn column) {
            if (((((((((((((((((((((((((((((column) == (this.columnOrderID))) || (((column) == (this.columnCustomerID))))) || (((column) == (this.columnEmployeeID))))) || (((column) == (this.columnOrderDate))))) || (((column) == (this.columnRequiredDate))))) || (((column) == (this.columnShippedDate))))) || (((column) == (this.columnShipVia))))) || (((column) == (this.columnFreight))))) || (((column) == (this.columnShipName))))) || (((column) == (this.columnShipAddress))))) || (((column) == (this.columnShipCity))))) || (((column) == (this.columnShipRegion))))) || (((column) == (this.columnShipPostalCode))))) || (((column) == (this.columnShipCountry))))) {
                throw new ArgumentException("Can't remove column since it it built in to this dataSet");
            }
        }
        protected override void OnRowChanged(DataRowChangeEventArgs e) {
            base.OnRowChanged(e);
            if (((this.OrdersRowChanged) == (null))) {
                this.OrdersRowChanged(this, new OrdersRowChangeEvent((OrdersRow)(e.Row), e.Action));
            }
        }
        protected override void OnRowChanging(DataRowChangeEventArgs e) {
            if (((this.OrdersRowChanging) != (null))) {
                this.OrdersRowChanging(this, new OrdersRowChangeEvent((OrdersRow)(e.Row), e.Action));
            }
        }
        protected virtual void OnOrderIDColumnChanging(DataColumnChangeEventArgs e) {
            if (((this.OrderIDColumnChanging) != (null))) {
                this.OrderIDColumnChanging(this, e);
            }
        }
        protected virtual void OnCustomerIDColumnChanging(DataColumnChangeEventArgs e) {
            if (((this.CustomerIDColumnChanging) != (null))) {
                this.CustomerIDColumnChanging(this, e);
            }
        }
        protected virtual void OnEmployeeIDColumnChanging(DataColumnChangeEventArgs e) {
            if (((this.EmployeeIDColumnChanging) != (null))) {
                this.EmployeeIDColumnChanging(this, e);
            }
        }
        protected virtual void OnOrderDateColumnChanging(DataColumnChangeEventArgs e) {
            if (((this.OrderDateColumnChanging) != (null))) {
                this.OrderDateColumnChanging(this, e);
            }
        }
        protected virtual void OnRequiredDateColumnChanging(DataColumnChangeEventArgs e) {
            if (((this.RequiredDateColumnChanging) != (null))) {
                this.RequiredDateColumnChanging(this, e);
            }
        }
        protected virtual void OnShippedDateColumnChanging(DataColumnChangeEventArgs e) {
            if (((this.ShippedDateColumnChanging) != (null))) {
                this.ShippedDateColumnChanging(this, e);
            }
        }
        protected virtual void OnShipViaColumnChanging(DataColumnChangeEventArgs e) {
            if (((this.ShipViaColumnChanging) != (null))) {
                this.ShipViaColumnChanging(this, e);
            }
        }
        protected virtual void OnFreightColumnChanging(DataColumnChangeEventArgs e) {
            if (((this.FreightColumnChanging) != (null))) {
                this.FreightColumnChanging(this, e);
            }
        }
        protected virtual void OnShipNameColumnChanging(DataColumnChangeEventArgs e) {
            if (((this.ShipNameColumnChanging) != (null))) {
                this.ShipNameColumnChanging(this, e);
            }
        }
        protected virtual void OnShipAddressColumnChanging(DataColumnChangeEventArgs e) {
            if (((this.ShipAddressColumnChanging) != (null))) {
                this.ShipAddressColumnChanging(this, e);
            }
        }
        protected virtual void OnShipCityColumnChanging(DataColumnChangeEventArgs e) {
            if (((this.ShipCityColumnChanging) != (null))) {
                this.ShipCityColumnChanging(this, e);
            }
        }
        protected virtual void OnShipRegionColumnChanging(DataColumnChangeEventArgs e) {
            if (((this.ShipRegionColumnChanging) != (null))) {
                this.ShipRegionColumnChanging(this, e);
            }
        }
        protected virtual void OnShipPostalCodeColumnChanging(DataColumnChangeEventArgs e) {
            if (((this.ShipPostalCodeColumnChanging) != (null))) {
                this.ShipPostalCodeColumnChanging(this, e);
            }
        }
        protected virtual void OnShipCountryColumnChanging(DataColumnChangeEventArgs e) {
            if (((this.ShipCountryColumnChanging) != (null))) {
                this.ShipCountryColumnChanging(this, e);
            }
        }
        protected override void OnColumnChanging(DataColumnChangeEventArgs e) {
            base.OnColumnChanging(e);
            if (((e.Column) == (this.columnOrderID))) {
                this.OnOrderIDColumnChanging(e);
            }
            else {
                if (((e.Column) == (this.columnCustomerID))) {
                    this.OnCustomerIDColumnChanging(e);
                }
                else {
                    if (((e.Column) == (this.columnEmployeeID))) {
                        this.OnEmployeeIDColumnChanging(e);
                    }
                    else {
                        if (((e.Column) == (this.columnOrderDate))) {
                            this.OnOrderDateColumnChanging(e);
                        }
                        else {
                            if (((e.Column) == (this.columnRequiredDate))) {
                                this.OnRequiredDateColumnChanging(e);
                            }
                            else {
                                if (((e.Column) == (this.columnShippedDate))) {
                                    this.OnShippedDateColumnChanging(e);
                                }
                                else {
                                    if (((e.Column) == (this.columnShipVia))) {
                                        this.OnShipViaColumnChanging(e);
                                    }
                                    else {
                                        if (((e.Column) == (this.columnFreight))) {
                                            this.OnFreightColumnChanging(e);
                                        }
                                        else {
                                            if (((e.Column) == (this.columnShipName))) {
                                                this.OnShipNameColumnChanging(e);
                                            }
                                            else {
                                                if (((e.Column) == (this.columnShipAddress))) {
                                                    this.OnShipAddressColumnChanging(e);
                                                }
                                                else {
                                                    if (((e.Column) == (this.columnShipCity))) {
                                                        this.OnShipCityColumnChanging(e);
                                                    }
                                                    else {
                                                        if (((e.Column) == (this.columnShipRegion))) {
                                                            this.OnShipRegionColumnChanging(e);
                                                        }
                                                        else {
                                                            if (((e.Column) == (this.columnShipPostalCode))) {
                                                                this.OnShipPostalCodeColumnChanging(e);
                                                            }
                                                            else {
                                                                if (((e.Column) == (this.columnShipCountry))) {
                                                                    this.OnShipCountryColumnChanging(e);
                                                                }
                                                            }
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
        public virtual void RemoveOrdersRow(OrdersRow rowOrdersRow) {
            this.Rows.Remove(rowOrdersRow);
        }
        public override bool ShouldPersistPrimaryKey() {
            return false;
        }
        public override void ResetPrimaryKey() {
        }
        public override bool ShouldPersistColumns() {
            return ((this.columnCount) != (this.Columns.Count));
        }
        public override void ResetColumns() {
            for (int i = 0; ((i) < (this.Columns.Count)); i = ((i) + (1))) {
                if (((((this.Columns[i]) == (this.columnShipCountry))) || (((((this.Columns[i]) == (this.columnShipPostalCode))) || (((((this.Columns[i]) == (this.columnShipRegion))) || (((((this.Columns[i]) == (this.columnShipCity))) || (((((this.Columns[i]) == (this.columnShipAddress))) || (((((this.Columns[i]) == (this.columnShipName))) || (((((this.Columns[i]) == (this.columnFreight))) || (((((this.Columns[i]) == (this.columnShipVia))) || (((((this.Columns[i]) == (this.columnShippedDate))) || (((((this.Columns[i]) == (this.columnRequiredDate))) || (((((this.Columns[i]) == (this.columnOrderDate))) || (((((this.Columns[i]) == (this.columnEmployeeID))) || (((((this.Columns[i]) == (this.columnCustomerID))) || (((this.Columns[i]) == (this.columnOrderID))))))))))))))))))))))))))))) {
                }
                else {
                    this.Columns.Remove(this.Columns[i]);
                }
            }
        }
        public override bool ShouldPersistConstraints() {
            return ((this.constraintCount) != (this.Constraints.Count));
        }
        public override void ResetConstraints() {
            for (int i = 0; ((i) < (this.Constraints.Count)); i = ((i) + (1))) {
                if (((((this.Constraints[i]) == (this.constraintCustomersOrders))) || (((this.Constraints[i]) == (this.constraintConstraint1))))) {
                }
                else {
                    this.Constraints.Remove(this.Constraints[i]);
                }
            }
        }
        
    }
    public class Orders_OrderID : System.Data.DataColumn {
        public Orders_OrderID() : 
                base("OrderID", typeof(int)) {
            this.InitClass();
        }
        
        public virtual void InitClass() {
            this.AutoIncrement = true;
            this.AllowNull = false;
            this.Unique = true;
        }
        
    }
    public class Orders_CustomerID : System.Data.DataColumn {
        public Orders_CustomerID() : 
                base("CustomerID", typeof(string)) {
            this.InitClass();
        }
        
        public virtual void InitClass() {
        }
        
    }
    public class Orders_EmployeeID : System.Data.DataColumn {
        public Orders_EmployeeID() : 
                base("EmployeeID", typeof(int)) {
            this.InitClass();
        }
        
        public virtual void InitClass() {
        }
        
    }
    public class Orders_OrderDate : System.Data.DataColumn {
        public Orders_OrderDate() : 
                base("OrderDate", typeof(System.DateTime)) {
            this.InitClass();
        }
        
        public virtual void InitClass() {
        }
        
    }
    public class Orders_RequiredDate : System.Data.DataColumn {
        public Orders_RequiredDate() : 
                base("RequiredDate", typeof(System.DateTime)) {
            this.InitClass();
        }
        
        public virtual void InitClass() {
        }
        
    }
    public class Orders_ShippedDate : System.Data.DataColumn {
        public Orders_ShippedDate() : 
                base("ShippedDate", typeof(System.DateTime)) {
            this.InitClass();
        }
        
        public virtual void InitClass() {
        }
        
    }
    public class Orders_ShipVia : System.Data.DataColumn {
        public Orders_ShipVia() : 
                base("ShipVia", typeof(int)) {
            this.InitClass();
        }
        
        public virtual void InitClass() {
        }
        
    }
    public class Orders_Freight : System.Data.DataColumn {
        public Orders_Freight() : 
                base("Freight", typeof(System.Currency)) {
            this.InitClass();
        }
        
        public virtual void InitClass() {
        }
        
    }
    public class Orders_ShipName : System.Data.DataColumn {
        public Orders_ShipName() : 
                base("ShipName", typeof(string)) {
            this.InitClass();
        }
        
        public virtual void InitClass() {
        }
        
    }
    public class Orders_ShipAddress : System.Data.DataColumn {
        public Orders_ShipAddress() : 
                base("ShipAddress", typeof(string)) {
            this.InitClass();
        }
        
        public virtual void InitClass() {
        }
        
    }
    public class Orders_ShipCity : System.Data.DataColumn {
        public Orders_ShipCity() : 
                base("ShipCity", typeof(string)) {
            this.InitClass();
        }
        
        public virtual void InitClass() {
        }
        
    }
    public class Orders_ShipRegion : System.Data.DataColumn {
        public Orders_ShipRegion() : 
                base("ShipRegion", typeof(string)) {
            this.InitClass();
        }
        
        public virtual void InitClass() {
        }
        
    }
    public class Orders_ShipPostalCode : System.Data.DataColumn {
        public Orders_ShipPostalCode() : 
                base("ShipPostalCode", typeof(string)) {
            this.InitClass();
        }
        
        public virtual void InitClass() {
        }
        
    }
    public class Orders_ShipCountry : System.Data.DataColumn {
        public Orders_ShipCountry() : 
                base("ShipCountry", typeof(string)) {
            this.InitClass();
        }
        
        public virtual void InitClass() {
        }
        
    }
    public class CustomersRow : DataRow {
        private Customers tableCustomers;
        
        public CustomersRow(DataRowBuilder rb) : 
                base(rb) {
            this.tableCustomers = (Customers)(this.Table);
        }
        
        public string CustomerID {
            virtual get {
                return (string)(this[this.tableCustomers.CustomerIDColumn]);
            }
            virtual set {
                this[this.tableCustomers.CustomerIDColumn] = value;
            }
        }
        public string CompanyName {
            virtual get {
                return (string)(this[this.tableCustomers.CompanyNameColumn]);
            }
            virtual set {
                this[this.tableCustomers.CompanyNameColumn] = value;
            }
        }
        public string ContactName {
            virtual get {
                return (string)(this[this.tableCustomers.ContactNameColumn]);
            }
            virtual set {
                this[this.tableCustomers.ContactNameColumn] = value;
            }
        }
        public bool ContactNameIsNull {
            virtual get {
                return this.IsNull(this.tableCustomers.ContactNameColumn);
            }
            virtual set {
                if (((value) == (true))) {
                    this[this.tableCustomers.ContactNameColumn] = Convert.DBNull;
                }
                else {
                    throw new ArgumentException("Can only set this property to true");
                }
            }
        }
        public string ContactTitle {
            virtual get {
                return (string)(this[this.tableCustomers.ContactTitleColumn]);
            }
            virtual set {
                this[this.tableCustomers.ContactTitleColumn] = value;
            }
        }
        public bool ContactTitleIsNull {
            virtual get {
                return this.IsNull(this.tableCustomers.ContactTitleColumn);
            }
            virtual set {
                if (((value) == (true))) {
                    this[this.tableCustomers.ContactTitleColumn] = Convert.DBNull;
                }
                else {
                    throw new ArgumentException("Can only set this property to true");
                }
            }
        }
        public string Address {
            virtual get {
                return (string)(this[this.tableCustomers.AddressColumn]);
            }
            virtual set {
                this[this.tableCustomers.AddressColumn] = value;
            }
        }
        public bool AddressIsNull {
            virtual get {
                return this.IsNull(this.tableCustomers.AddressColumn);
            }
            virtual set {
                if (((value) == (true))) {
                    this[this.tableCustomers.AddressColumn] = Convert.DBNull;
                }
                else {
                    throw new ArgumentException("Can only set this property to true");
                }
            }
        }
        public string City {
            virtual get {
                return (string)(this[this.tableCustomers.CityColumn]);
            }
            virtual set {
                this[this.tableCustomers.CityColumn] = value;
            }
        }
        public bool CityIsNull {
            virtual get {
                return this.IsNull(this.tableCustomers.CityColumn);
            }
            virtual set {
                if (((value) == (true))) {
                    this[this.tableCustomers.CityColumn] = Convert.DBNull;
                }
                else {
                    throw new ArgumentException("Can only set this property to true");
                }
            }
        }
        public string Region {
            virtual get {
                return (string)(this[this.tableCustomers.RegionColumn]);
            }
            virtual set {
                this[this.tableCustomers.RegionColumn] = value;
            }
        }
        public bool RegionIsNull {
            virtual get {
                return this.IsNull(this.tableCustomers.RegionColumn);
            }
            virtual set {
                if (((value) == (true))) {
                    this[this.tableCustomers.RegionColumn] = Convert.DBNull;
                }
                else {
                    throw new ArgumentException("Can only set this property to true");
                }
            }
        }
        public string PostalCode {
            virtual get {
                return (string)(this[this.tableCustomers.PostalCodeColumn]);
            }
            virtual set {
                this[this.tableCustomers.PostalCodeColumn] = value;
            }
        }
        public bool PostalCodeIsNull {
            virtual get {
                return this.IsNull(this.tableCustomers.PostalCodeColumn);
            }
            virtual set {
                if (((value) == (true))) {
                    this[this.tableCustomers.PostalCodeColumn] = Convert.DBNull;
                }
                else {
                    throw new ArgumentException("Can only set this property to true");
                }
            }
        }
        public string Country {
            virtual get {
                return (string)(this[this.tableCustomers.CountryColumn]);
            }
            virtual set {
                this[this.tableCustomers.CountryColumn] = value;
            }
        }
        public bool CountryIsNull {
            virtual get {
                return this.IsNull(this.tableCustomers.CountryColumn);
            }
            virtual set {
                if (((value) == (true))) {
                    this[this.tableCustomers.CountryColumn] = Convert.DBNull;
                }
                else {
                    throw new ArgumentException("Can only set this property to true");
                }
            }
        }
        public string Phone {
            virtual get {
                return (string)(this[this.tableCustomers.PhoneColumn]);
            }
            virtual set {
                this[this.tableCustomers.PhoneColumn] = value;
            }
        }
        public bool PhoneIsNull {
            virtual get {
                return this.IsNull(this.tableCustomers.PhoneColumn);
            }
            virtual set {
                if (((value) == (true))) {
                    this[this.tableCustomers.PhoneColumn] = Convert.DBNull;
                }
                else {
                    throw new ArgumentException("Can only set this property to true");
                }
            }
        }
        public string Fax {
            virtual get {
                return (string)(this[this.tableCustomers.FaxColumn]);
            }
            virtual set {
                this[this.tableCustomers.FaxColumn] = value;
            }
        }
        public bool FaxIsNull {
            virtual get {
                return this.IsNull(this.tableCustomers.FaxColumn);
            }
            virtual set {
                if (((value) == (true))) {
                    this[this.tableCustomers.FaxColumn] = Convert.DBNull;
                }
                else {
                    throw new ArgumentException("Can only set this property to true");
                }
            }
        }
        public OrdersRow[] OrdersByCustomersOrders {
            virtual get {
                return (OrdersRow[])(this.GetChildRows(this.Table.ChildRelations["CustomersOrders"]));
            }
        }
        
    }
    public class OrdersRow : DataRow {
        private Orders tableOrders;
        
        public OrdersRow(DataRowBuilder rb) : 
                base(rb) {
            this.tableOrders = (Orders)(this.Table);
        }
        
        public int OrderID {
            virtual get {
                return (int)(this[this.tableOrders.OrderIDColumn]);
            }
            virtual set {
                this[this.tableOrders.OrderIDColumn] = value;
            }
        }
        public string CustomerID {
            virtual get {
                return (string)(this[this.tableOrders.CustomerIDColumn]);
            }
            virtual set {
                this[this.tableOrders.CustomerIDColumn] = value;
            }
        }
        public bool CustomerIDIsNull {
            virtual get {
                return this.IsNull(this.tableOrders.CustomerIDColumn);
            }
            virtual set {
                if (((value) == (true))) {
                    this[this.tableOrders.CustomerIDColumn] = Convert.DBNull;
                }
                else {
                    throw new ArgumentException("Can only set this property to true");
                }
            }
        }
        public int EmployeeID {
            virtual get {
                return (int)(this[this.tableOrders.EmployeeIDColumn]);
            }
            virtual set {
                this[this.tableOrders.EmployeeIDColumn] = value;
            }
        }
        public bool EmployeeIDIsNull {
            virtual get {
                return this.IsNull(this.tableOrders.EmployeeIDColumn);
            }
            virtual set {
                if (((value) == (true))) {
                    this[this.tableOrders.EmployeeIDColumn] = Convert.DBNull;
                }
                else {
                    throw new ArgumentException("Can only set this property to true");
                }
            }
        }
        public System.DateTime OrderDate {
            virtual get {
                return (System.DateTime)(this[this.tableOrders.OrderDateColumn]);
            }
            virtual set {
                this[this.tableOrders.OrderDateColumn] = value;
            }
        }
        public bool OrderDateIsNull {
            virtual get {
                return this.IsNull(this.tableOrders.OrderDateColumn);
            }
            virtual set {
                if (((value) == (true))) {
                    this[this.tableOrders.OrderDateColumn] = Convert.DBNull;
                }
                else {
                    throw new ArgumentException("Can only set this property to true");
                }
            }
        }
        public System.DateTime RequiredDate {
            virtual get {
                return (System.DateTime)(this[this.tableOrders.RequiredDateColumn]);
            }
            virtual set {
                this[this.tableOrders.RequiredDateColumn] = value;
            }
        }
        public bool RequiredDateIsNull {
            virtual get {
                return this.IsNull(this.tableOrders.RequiredDateColumn);
            }
            virtual set {
                if (((value) == (true))) {
                    this[this.tableOrders.RequiredDateColumn] = Convert.DBNull;
                }
                else {
                    throw new ArgumentException("Can only set this property to true");
                }
            }
        }
        public System.DateTime ShippedDate {
            virtual get {
                return (System.DateTime)(this[this.tableOrders.ShippedDateColumn]);
            }
            virtual set {
                this[this.tableOrders.ShippedDateColumn] = value;
            }
        }
        public bool ShippedDateIsNull {
            virtual get {
                return this.IsNull(this.tableOrders.ShippedDateColumn);
            }
            virtual set {
                if (((value) == (true))) {
                    this[this.tableOrders.ShippedDateColumn] = Convert.DBNull;
                }
                else {
                    throw new ArgumentException("Can only set this property to true");
                }
            }
        }
        public int ShipVia {
            virtual get {
                return (int)(this[this.tableOrders.ShipViaColumn]);
            }
            virtual set {
                this[this.tableOrders.ShipViaColumn] = value;
            }
        }
        public bool ShipViaIsNull {
            virtual get {
                return this.IsNull(this.tableOrders.ShipViaColumn);
            }
            virtual set {
                if (((value) == (true))) {
                    this[this.tableOrders.ShipViaColumn] = Convert.DBNull;
                }
                else {
                    throw new ArgumentException("Can only set this property to true");
                }
            }
        }
        public System.Currency Freight {
            virtual get {
                return (System.Currency)(this[this.tableOrders.FreightColumn]);
            }
            virtual set {
                this[this.tableOrders.FreightColumn] = value;
            }
        }
        public bool FreightIsNull {
            virtual get {
                return this.IsNull(this.tableOrders.FreightColumn);
            }
            virtual set {
                if (((value) == (true))) {
                    this[this.tableOrders.FreightColumn] = Convert.DBNull;
                }
                else {
                    throw new ArgumentException("Can only set this property to true");
                }
            }
        }
        public string ShipName {
            virtual get {
                return (string)(this[this.tableOrders.ShipNameColumn]);
            }
            virtual set {
                this[this.tableOrders.ShipNameColumn] = value;
            }
        }
        public bool ShipNameIsNull {
            virtual get {
                return this.IsNull(this.tableOrders.ShipNameColumn);
            }
            virtual set {
                if (((value) == (true))) {
                    this[this.tableOrders.ShipNameColumn] = Convert.DBNull;
                }
                else {
                    throw new ArgumentException("Can only set this property to true");
                }
            }
        }
        public string ShipAddress {
            virtual get {
                return (string)(this[this.tableOrders.ShipAddressColumn]);
            }
            virtual set {
                this[this.tableOrders.ShipAddressColumn] = value;
            }
        }
        public bool ShipAddressIsNull {
            virtual get {
                return this.IsNull(this.tableOrders.ShipAddressColumn);
            }
            virtual set {
                if (((value) == (true))) {
                    this[this.tableOrders.ShipAddressColumn] = Convert.DBNull;
                }
                else {
                    throw new ArgumentException("Can only set this property to true");
                }
            }
        }
        public string ShipCity {
            virtual get {
                return (string)(this[this.tableOrders.ShipCityColumn]);
            }
            virtual set {
                this[this.tableOrders.ShipCityColumn] = value;
            }
        }
        public bool ShipCityIsNull {
            virtual get {
                return this.IsNull(this.tableOrders.ShipCityColumn);
            }
            virtual set {
                if (((value) == (true))) {
                    this[this.tableOrders.ShipCityColumn] = Convert.DBNull;
                }
                else {
                    throw new ArgumentException("Can only set this property to true");
                }
            }
        }
        public string ShipRegion {
            virtual get {
                return (string)(this[this.tableOrders.ShipRegionColumn]);
            }
            virtual set {
                this[this.tableOrders.ShipRegionColumn] = value;
            }
        }
        public bool ShipRegionIsNull {
            virtual get {
                return this.IsNull(this.tableOrders.ShipRegionColumn);
            }
            virtual set {
                if (((value) == (true))) {
                    this[this.tableOrders.ShipRegionColumn] = Convert.DBNull;
                }
                else {
                    throw new ArgumentException("Can only set this property to true");
                }
            }
        }
        public string ShipPostalCode {
            virtual get {
                return (string)(this[this.tableOrders.ShipPostalCodeColumn]);
            }
            virtual set {
                this[this.tableOrders.ShipPostalCodeColumn] = value;
            }
        }
        public bool ShipPostalCodeIsNull {
            virtual get {
                return this.IsNull(this.tableOrders.ShipPostalCodeColumn);
            }
            virtual set {
                if (((value) == (true))) {
                    this[this.tableOrders.ShipPostalCodeColumn] = Convert.DBNull;
                }
                else {
                    throw new ArgumentException("Can only set this property to true");
                }
            }
        }
        public string ShipCountry {
            virtual get {
                return (string)(this[this.tableOrders.ShipCountryColumn]);
            }
            virtual set {
                this[this.tableOrders.ShipCountryColumn] = value;
            }
        }
        public bool ShipCountryIsNull {
            virtual get {
                return this.IsNull(this.tableOrders.ShipCountryColumn);
            }
            virtual set {
                if (((value) == (true))) {
                    this[this.tableOrders.ShipCountryColumn] = Convert.DBNull;
                }
                else {
                    throw new ArgumentException("Can only set this property to true");
                }
            }
        }
        public CustomersRow CustomersRowByCustomersOrders {
            virtual get {
                return (CustomersRow)(this.GetParentRow(this.Table.ParentRelations["CustomersOrders"]));
            }
            virtual set {
                this.Table.ParentRelations["CustomersOrders"].SetParentRow(this, value);
            }
        }
        
    }
    public class CustomersRowChangeEvent : EventArgs {
        private CustomersRow rowCustomersRow;
        private System.Data.DataRowAction actionValue;
        
        public CustomersRowChangeEvent(CustomersRow rowCustomersRowArg, DataRowAction actionArg) {
            this.rowCustomersRow = rowCustomersRowArg;
            this.actionValue = actionArg;
        }
        
        public CustomersRow CustomersRow {
            virtual get {
                return this.rowCustomersRow;
            }
        }
        public DataRowAction Action {
            virtual get {
                return this.actionValue;
            }
        }
        
    }
    public class OrdersRowChangeEvent : EventArgs {
        private OrdersRow rowOrdersRow;
        private System.Data.DataRowAction actionValue;
        
        public OrdersRowChangeEvent(OrdersRow rowOrdersRowArg, DataRowAction actionArg) {
            this.rowOrdersRow = rowOrdersRowArg;
            this.actionValue = actionArg;
        }
        
        public OrdersRow OrdersRow {
            virtual get {
                return this.rowOrdersRow;
            }
        }
        public DataRowAction Action {
            virtual get {
                return this.actionValue;
            }
        }
        
    }
    public delegate void CustomersRowChangeEventHandler(object sender, CustomersRowChangeEvent e);
    public delegate void OrdersRowChangeEventHandler(object sender, OrdersRowChangeEvent e);
}
